/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */
package com.revenuecat.purchases;

public final class R {
	public static final class string {
		public static int app_name = 0x7f020000;
	}
}
