/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */
package com.facebook.fbui.textlayoutbuilder;

public final class R {
	public static final class styleable {
		public static final int[] TextAppearance = { 0x01010095, 0x01010096, 0x01010097, 0x01010098, 0x01010161, 0x01010162, 0x01010163, 0x01010164, 0x7f010024 };
		public static final int TextAppearance_android_shadowColor = 4;
		public static final int TextAppearance_android_shadowDx = 5;
		public static final int TextAppearance_android_shadowDy = 6;
		public static final int TextAppearance_android_shadowRadius = 7;
		public static final int TextAppearance_android_textColor = 3;
		public static final int TextAppearance_android_textSize = 0;
		public static final int TextAppearance_android_textStyle = 2;
		public static final int[] TextStyle = { 0x01010034, 0x01010095, 0x01010097, 0x01010098, 0x010100ab, 0x01010153, 0x0101015d, 0x01010161, 0x01010162, 0x01010163, 0x01010164 };
		public static final int TextStyle_android_ellipsize = 4;
		public static final int TextStyle_android_maxLines = 5;
		public static final int TextStyle_android_shadowColor = 7;
		public static final int TextStyle_android_shadowDx = 8;
		public static final int TextStyle_android_shadowDy = 9;
		public static final int TextStyle_android_shadowRadius = 10;
		public static final int TextStyle_android_singleLine = 6;
		public static final int TextStyle_android_textAppearance = 0;
		public static final int TextStyle_android_textColor = 3;
		public static final int TextStyle_android_textSize = 1;
		public static final int TextStyle_android_textStyle = 2;
	}
}
