/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */

package com.revenuecat.purchases_sample;

public final class R {
    public static final class anim {
        public static final int abc_fade_in=0x7f050000;
        public static final int abc_fade_out=0x7f050001;
        public static final int abc_grow_fade_in_from_bottom=0x7f050002;
        public static final int abc_popup_enter=0x7f050003;
        public static final int abc_popup_exit=0x7f050004;
        public static final int abc_shrink_fade_out_from_bottom=0x7f050005;
        public static final int abc_slide_in_bottom=0x7f050006;
        public static final int abc_slide_in_top=0x7f050007;
        public static final int abc_slide_out_bottom=0x7f050008;
        public static final int abc_slide_out_top=0x7f050009;
        public static final int catalyst_fade_in=0x7f05000a;
        public static final int catalyst_fade_out=0x7f05000b;
        public static final int catalyst_push_up_in=0x7f05000c;
        public static final int catalyst_push_up_out=0x7f05000d;
        public static final int catalyst_slide_down=0x7f05000e;
        public static final int catalyst_slide_up=0x7f05000f;
    }
    public static final class attr {
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarDivider=0x7f01007d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarItemBackground=0x7f01007e;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarPopupTheme=0x7f010077;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
<p>May be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>wrap_content</code></td><td>0</td><td></td></tr>
</table>
         */
        public static final int actionBarSize=0x7f01007c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarSplitStyle=0x7f010079;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarStyle=0x7f010078;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarTabBarStyle=0x7f010073;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarTabStyle=0x7f010072;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarTabTextStyle=0x7f010074;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarTheme=0x7f01007a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionBarWidgetTheme=0x7f01007b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionButtonStyle=0x7f010097;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionDropDownStyle=0x7f010093;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionLayout=0x7f01004c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionMenuTextAppearance=0x7f01007f;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int actionMenuTextColor=0x7f010080;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeBackground=0x7f010083;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeCloseButtonStyle=0x7f010082;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeCloseDrawable=0x7f010085;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeCopyDrawable=0x7f010087;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeCutDrawable=0x7f010086;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeFindDrawable=0x7f01008b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModePasteDrawable=0x7f010088;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModePopupWindowStyle=0x7f01008d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeSelectAllDrawable=0x7f010089;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeShareDrawable=0x7f01008a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeSplitBackground=0x7f010084;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeStyle=0x7f010081;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionModeWebSearchDrawable=0x7f01008c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionOverflowButtonStyle=0x7f010075;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actionOverflowMenuStyle=0x7f010076;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int actionProviderClass=0x7f01004e;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int actionViewClass=0x7f01004d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int activityChooserViewStyle=0x7f01009f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int actualImageResource=0x7f010060;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static final int actualImageScaleType=0x7f01003a;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int actualImageUri=0x7f01005f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int alertDialogButtonGroupStyle=0x7f0100c1;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int alertDialogCenterButtons=0x7f0100c2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int alertDialogStyle=0x7f0100c0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int alertDialogTheme=0x7f0100c3;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int arrowHeadLength=0x7f01002b;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int arrowShaftLength=0x7f01002c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int autoCompleteTextViewStyle=0x7f0100c8;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int background=0x7f01000c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int backgroundImage=0x7f01003b;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int backgroundSplit=0x7f01000e;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int backgroundStacked=0x7f01000d;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int backgroundTint=0x7f0100e4;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
         */
        public static final int backgroundTintMode=0x7f0100e5;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int barLength=0x7f01002d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int borderlessButtonStyle=0x7f01009c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonBarButtonStyle=0x7f010099;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonBarNegativeButtonStyle=0x7f0100c6;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonBarNeutralButtonStyle=0x7f0100c7;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonBarPositiveButtonStyle=0x7f0100c5;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonBarStyle=0x7f010098;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonPanelSideLayout=0x7f01001f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonStyle=0x7f0100c9;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int buttonStyleSmall=0x7f0100ca;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int buttonTint=0x7f010025;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
         */
        public static final int buttonTintMode=0x7f010026;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int checkboxStyle=0x7f0100cb;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int checkedTextViewStyle=0x7f0100cc;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int closeIcon=0x7f010056;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int closeItemLayout=0x7f01001c;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int collapseContentDescription=0x7f0100db;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int collapseIcon=0x7f0100da;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int color=0x7f010027;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorAccent=0x7f0100b9;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorButtonNormal=0x7f0100bd;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorControlActivated=0x7f0100bb;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorControlHighlight=0x7f0100bc;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorControlNormal=0x7f0100ba;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorPrimary=0x7f0100b7;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorPrimaryDark=0x7f0100b8;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int colorSwitchThumbNormal=0x7f0100be;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int commitIcon=0x7f01005b;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int contentInsetEnd=0x7f010017;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int contentInsetLeft=0x7f010018;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int contentInsetRight=0x7f010019;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int contentInsetStart=0x7f010016;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int controlBackground=0x7f0100bf;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int customNavigationLayout=0x7f01000f;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int defaultQueryHint=0x7f010055;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int dialogPreferredPadding=0x7f010091;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int dialogTheme=0x7f010090;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>useLogo</code></td><td>0x1</td><td></td></tr>
<tr><td><code>showHome</code></td><td>0x2</td><td></td></tr>
<tr><td><code>homeAsUp</code></td><td>0x4</td><td></td></tr>
<tr><td><code>showTitle</code></td><td>0x8</td><td></td></tr>
<tr><td><code>showCustom</code></td><td>0x10</td><td></td></tr>
<tr><td><code>disableHome</code></td><td>0x20</td><td></td></tr>
</table>
         */
        public static final int displayOptions=0x7f010005;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int divider=0x7f01000b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int dividerHorizontal=0x7f01009e;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int dividerPadding=0x7f01004a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int dividerVertical=0x7f01009d;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int drawableSize=0x7f010029;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int drawerArrowStyle=0x7f010000;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int dropDownListViewStyle=0x7f0100af;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int dropdownListPreferredItemHeight=0x7f010094;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int editTextBackground=0x7f0100a5;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int editTextColor=0x7f0100a4;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int editTextStyle=0x7f0100cd;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int elevation=0x7f01001a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int expandActivityOverflowButtonDrawable=0x7f01001e;
        /** <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int fadeDuration=0x7f01002f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int failureImage=0x7f010035;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static final int failureImageScaleType=0x7f010036;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int gapBetweenBars=0x7f01002a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int goIcon=0x7f010057;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int height=0x7f010001;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int hideOnContentScroll=0x7f010015;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int homeAsUpIndicator=0x7f010096;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int homeLayout=0x7f010010;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int icon=0x7f010009;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int iconifiedByDefault=0x7f010053;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int indeterminateProgressStyle=0x7f010012;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int initialActivityCount=0x7f01001d;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int isLightTheme=0x7f010002;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int itemPadding=0x7f010014;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int layout=0x7f010052;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int listChoiceBackgroundIndicator=0x7f0100b6;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int listDividerAlertDialog=0x7f010092;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int listItemLayout=0x7f010023;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int listLayout=0x7f010020;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int listPopupWindowStyle=0x7f0100b0;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int listPreferredItemHeight=0x7f0100aa;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int listPreferredItemHeightLarge=0x7f0100ac;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int listPreferredItemHeightSmall=0x7f0100ab;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int listPreferredItemPaddingLeft=0x7f0100ad;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int listPreferredItemPaddingRight=0x7f0100ae;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int logo=0x7f01000a;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int logoDescription=0x7f0100de;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int maxButtonHeight=0x7f0100d9;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int measureWithLargestChild=0x7f010048;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int multiChoiceItemLayout=0x7f010021;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int navigationContentDescription=0x7f0100dd;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int navigationIcon=0x7f0100dc;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>normal</code></td><td>0</td><td></td></tr>
<tr><td><code>listMode</code></td><td>1</td><td></td></tr>
<tr><td><code>tabMode</code></td><td>2</td><td></td></tr>
</table>
         */
        public static final int navigationMode=0x7f010004;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int overlapAnchor=0x7f010050;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int overlayImage=0x7f01003c;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int paddingEnd=0x7f0100e2;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int paddingStart=0x7f0100e1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int panelBackground=0x7f0100b3;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int panelMenuListTheme=0x7f0100b5;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int panelMenuListWidth=0x7f0100b4;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int placeholderImage=0x7f010031;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static final int placeholderImageScaleType=0x7f010032;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int popupMenuStyle=0x7f0100a2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int popupTheme=0x7f01001b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int popupWindowStyle=0x7f0100a3;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int preserveIconSpacing=0x7f01004f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int pressedStateOverlayImage=0x7f01003d;
        /** <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int progressBarAutoRotateInterval=0x7f010039;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int progressBarImage=0x7f010037;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static final int progressBarImageScaleType=0x7f010038;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int progressBarPadding=0x7f010013;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int progressBarStyle=0x7f010011;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int queryBackground=0x7f01005d;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int queryHint=0x7f010054;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int radioButtonStyle=0x7f0100ce;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int ratingBarStyle=0x7f0100cf;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int retryImage=0x7f010033;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static final int retryImageScaleType=0x7f010034;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundAsCircle=0x7f01003e;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundBottomLeft=0x7f010043;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundBottomRight=0x7f010042;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundTopLeft=0x7f010040;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundTopRight=0x7f010041;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundWithOverlayColor=0x7f010044;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundedCornerRadius=0x7f01003f;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundingBorderColor=0x7f010046;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundingBorderPadding=0x7f010047;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int roundingBorderWidth=0x7f010045;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int searchHintIcon=0x7f010059;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int searchIcon=0x7f010058;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int searchViewStyle=0x7f0100a9;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int selectableItemBackground=0x7f01009a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int selectableItemBackgroundBorderless=0x7f01009b;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>never</code></td><td>0</td><td></td></tr>
<tr><td><code>ifRoom</code></td><td>1</td><td></td></tr>
<tr><td><code>always</code></td><td>2</td><td></td></tr>
<tr><td><code>withText</code></td><td>4</td><td></td></tr>
<tr><td><code>collapseActionView</code></td><td>8</td><td></td></tr>
</table>
         */
        public static final int showAsAction=0x7f01004b;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>beginning</code></td><td>1</td><td></td></tr>
<tr><td><code>middle</code></td><td>2</td><td></td></tr>
<tr><td><code>end</code></td><td>4</td><td></td></tr>
</table>
         */
        public static final int showDividers=0x7f010049;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int showText=0x7f010067;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int singleChoiceItemLayout=0x7f010022;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int spinBars=0x7f010028;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int spinnerDropDownItemStyle=0x7f010095;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int spinnerStyle=0x7f0100d0;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int splitTrack=0x7f010066;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int state_above_anchor=0x7f010051;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int submitBackground=0x7f01005e;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int subtitle=0x7f010006;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int subtitleTextAppearance=0x7f0100d3;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int subtitleTextColor=0x7f0100e0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int subtitleTextStyle=0x7f010008;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int suggestionRowLayout=0x7f01005c;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int switchMinWidth=0x7f010064;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int switchPadding=0x7f010065;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int switchStyle=0x7f0100d1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int switchTextAppearance=0x7f010063;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
         */
        public static final int textAllCaps=0x7f010024;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceLargePopupMenu=0x7f01008e;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceListItem=0x7f0100b1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceListItemSmall=0x7f0100b2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceSearchResultSubtitle=0x7f0100a7;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceSearchResultTitle=0x7f0100a6;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int textAppearanceSmallPopupMenu=0x7f01008f;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int textColorAlertDialogListItem=0x7f0100c4;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static final int textColorSearchUrl=0x7f0100a8;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int theme=0x7f0100e3;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int thickness=0x7f01002e;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int thumbTextPadding=0x7f010062;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int title=0x7f010003;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleMarginBottom=0x7f0100d8;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleMarginEnd=0x7f0100d6;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleMarginStart=0x7f0100d5;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleMarginTop=0x7f0100d7;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleMargins=0x7f0100d4;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int titleTextAppearance=0x7f0100d2;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int titleTextColor=0x7f0100df;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int titleTextStyle=0x7f010007;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int toolbarNavigationButtonStyle=0x7f0100a1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int toolbarStyle=0x7f0100a0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int track=0x7f010061;
        /** <p>Must be a floating point value, such as "<code>1.2</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int viewAspectRatio=0x7f010030;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static final int voiceIcon=0x7f01005a;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowActionBar=0x7f010068;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowActionBarOverlay=0x7f01006a;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowActionModeOverlay=0x7f01006b;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowFixedHeightMajor=0x7f01006f;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowFixedHeightMinor=0x7f01006d;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowFixedWidthMajor=0x7f01006c;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowFixedWidthMinor=0x7f01006e;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowMinWidthMajor=0x7f010070;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowMinWidthMinor=0x7f010071;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static final int windowNoTitle=0x7f010069;
    }
    public static final class bool {
        public static final int abc_action_bar_embed_tabs=0x7f0a0002;
        public static final int abc_action_bar_embed_tabs_pre_jb=0x7f0a0000;
        public static final int abc_action_bar_expanded_action_views_exclusive=0x7f0a0003;
        public static final int abc_config_actionMenuItemAllCaps=0x7f0a0004;
        public static final int abc_config_allowActionMenuItemTextWithIcon=0x7f0a0001;
        public static final int abc_config_closeDialogWhenTouchOutside=0x7f0a0005;
        public static final int abc_config_showMenuShortcutsWhenKeyboardPresent=0x7f0a0006;
    }
    public static final class color {
        public static final int abc_background_cache_hint_selector_material_dark=0x7f0c003b;
        public static final int abc_background_cache_hint_selector_material_light=0x7f0c003c;
        public static final int abc_color_highlight_material=0x7f0c003d;
        public static final int abc_input_method_navigation_guard=0x7f0c0000;
        public static final int abc_primary_text_disable_only_material_dark=0x7f0c003e;
        public static final int abc_primary_text_disable_only_material_light=0x7f0c003f;
        public static final int abc_primary_text_material_dark=0x7f0c0040;
        public static final int abc_primary_text_material_light=0x7f0c0041;
        public static final int abc_search_url_text=0x7f0c0042;
        public static final int abc_search_url_text_normal=0x7f0c0001;
        public static final int abc_search_url_text_pressed=0x7f0c0002;
        public static final int abc_search_url_text_selected=0x7f0c0003;
        public static final int abc_secondary_text_material_dark=0x7f0c0043;
        public static final int abc_secondary_text_material_light=0x7f0c0044;
        public static final int accent_material_dark=0x7f0c0004;
        public static final int accent_material_light=0x7f0c0005;
        public static final int background_floating_material_dark=0x7f0c0006;
        public static final int background_floating_material_light=0x7f0c0007;
        public static final int background_material_dark=0x7f0c0008;
        public static final int background_material_light=0x7f0c0009;
        public static final int bright_foreground_disabled_material_dark=0x7f0c000a;
        public static final int bright_foreground_disabled_material_light=0x7f0c000b;
        public static final int bright_foreground_inverse_material_dark=0x7f0c000c;
        public static final int bright_foreground_inverse_material_light=0x7f0c000d;
        public static final int bright_foreground_material_dark=0x7f0c000e;
        public static final int bright_foreground_material_light=0x7f0c000f;
        public static final int button_material_dark=0x7f0c0010;
        public static final int button_material_light=0x7f0c0011;
        public static final int catalyst_redbox_background=0x7f0c0012;
        public static final int dim_foreground_disabled_material_dark=0x7f0c0013;
        public static final int dim_foreground_disabled_material_light=0x7f0c0014;
        public static final int dim_foreground_material_dark=0x7f0c0015;
        public static final int dim_foreground_material_light=0x7f0c0016;
        public static final int foreground_material_dark=0x7f0c0017;
        public static final int foreground_material_light=0x7f0c0018;
        public static final int highlighted_text_material_dark=0x7f0c0019;
        public static final int highlighted_text_material_light=0x7f0c001a;
        public static final int hint_foreground_material_dark=0x7f0c001b;
        public static final int hint_foreground_material_light=0x7f0c001c;
        public static final int material_blue_grey_800=0x7f0c001d;
        public static final int material_blue_grey_900=0x7f0c001e;
        public static final int material_blue_grey_950=0x7f0c001f;
        public static final int material_deep_teal_200=0x7f0c0020;
        public static final int material_deep_teal_500=0x7f0c0021;
        public static final int material_grey_100=0x7f0c0022;
        public static final int material_grey_300=0x7f0c0023;
        public static final int material_grey_50=0x7f0c0024;
        public static final int material_grey_600=0x7f0c0025;
        public static final int material_grey_800=0x7f0c0026;
        public static final int material_grey_850=0x7f0c0027;
        public static final int material_grey_900=0x7f0c0028;
        public static final int primary_dark_material_dark=0x7f0c0029;
        public static final int primary_dark_material_light=0x7f0c002a;
        public static final int primary_material_dark=0x7f0c002b;
        public static final int primary_material_light=0x7f0c002c;
        public static final int primary_text_default_material_dark=0x7f0c002d;
        public static final int primary_text_default_material_light=0x7f0c002e;
        public static final int primary_text_disabled_material_dark=0x7f0c002f;
        public static final int primary_text_disabled_material_light=0x7f0c0030;
        public static final int ripple_material_dark=0x7f0c0031;
        public static final int ripple_material_light=0x7f0c0032;
        public static final int secondary_text_default_material_dark=0x7f0c0033;
        public static final int secondary_text_default_material_light=0x7f0c0034;
        public static final int secondary_text_disabled_material_dark=0x7f0c0035;
        public static final int secondary_text_disabled_material_light=0x7f0c0036;
        public static final int switch_thumb_disabled_material_dark=0x7f0c0037;
        public static final int switch_thumb_disabled_material_light=0x7f0c0038;
        public static final int switch_thumb_material_dark=0x7f0c0045;
        public static final int switch_thumb_material_light=0x7f0c0046;
        public static final int switch_thumb_normal_material_dark=0x7f0c0039;
        public static final int switch_thumb_normal_material_light=0x7f0c003a;
    }
    public static final class dimen {
        public static final int abc_action_bar_content_inset_material=0x7f08000b;
        public static final int abc_action_bar_default_height_material=0x7f080001;
        public static final int abc_action_bar_default_padding_end_material=0x7f08000c;
        public static final int abc_action_bar_default_padding_start_material=0x7f08000d;
        public static final int abc_action_bar_icon_vertical_padding_material=0x7f08000f;
        public static final int abc_action_bar_overflow_padding_end_material=0x7f080010;
        public static final int abc_action_bar_overflow_padding_start_material=0x7f080011;
        public static final int abc_action_bar_progress_bar_size=0x7f080002;
        public static final int abc_action_bar_stacked_max_height=0x7f080012;
        public static final int abc_action_bar_stacked_tab_max_width=0x7f080013;
        public static final int abc_action_bar_subtitle_bottom_margin_material=0x7f080014;
        public static final int abc_action_bar_subtitle_top_margin_material=0x7f080015;
        public static final int abc_action_button_min_height_material=0x7f080016;
        public static final int abc_action_button_min_width_material=0x7f080017;
        public static final int abc_action_button_min_width_overflow_material=0x7f080018;
        public static final int abc_alert_dialog_button_bar_height=0x7f080000;
        public static final int abc_button_inset_horizontal_material=0x7f080019;
        public static final int abc_button_inset_vertical_material=0x7f08001a;
        public static final int abc_button_padding_horizontal_material=0x7f08001b;
        public static final int abc_button_padding_vertical_material=0x7f08001c;
        public static final int abc_config_prefDialogWidth=0x7f080005;
        public static final int abc_control_corner_material=0x7f08001d;
        public static final int abc_control_inset_material=0x7f08001e;
        public static final int abc_control_padding_material=0x7f08001f;
        public static final int abc_dialog_list_padding_vertical_material=0x7f080020;
        public static final int abc_dialog_min_width_major=0x7f080021;
        public static final int abc_dialog_min_width_minor=0x7f080022;
        public static final int abc_dialog_padding_material=0x7f080023;
        public static final int abc_dialog_padding_top_material=0x7f080024;
        public static final int abc_disabled_alpha_material_dark=0x7f080025;
        public static final int abc_disabled_alpha_material_light=0x7f080026;
        public static final int abc_dropdownitem_icon_width=0x7f080027;
        public static final int abc_dropdownitem_text_padding_left=0x7f080028;
        public static final int abc_dropdownitem_text_padding_right=0x7f080029;
        public static final int abc_edit_text_inset_bottom_material=0x7f08002a;
        public static final int abc_edit_text_inset_horizontal_material=0x7f08002b;
        public static final int abc_edit_text_inset_top_material=0x7f08002c;
        public static final int abc_floating_window_z=0x7f08002d;
        public static final int abc_list_item_padding_horizontal_material=0x7f08002e;
        public static final int abc_panel_menu_list_width=0x7f08002f;
        public static final int abc_search_view_preferred_width=0x7f080030;
        public static final int abc_search_view_text_min_width=0x7f080006;
        public static final int abc_switch_padding=0x7f08000e;
        public static final int abc_text_size_body_1_material=0x7f080031;
        public static final int abc_text_size_body_2_material=0x7f080032;
        public static final int abc_text_size_button_material=0x7f080033;
        public static final int abc_text_size_caption_material=0x7f080034;
        public static final int abc_text_size_display_1_material=0x7f080035;
        public static final int abc_text_size_display_2_material=0x7f080036;
        public static final int abc_text_size_display_3_material=0x7f080037;
        public static final int abc_text_size_display_4_material=0x7f080038;
        public static final int abc_text_size_headline_material=0x7f080039;
        public static final int abc_text_size_large_material=0x7f08003a;
        public static final int abc_text_size_medium_material=0x7f08003b;
        public static final int abc_text_size_menu_material=0x7f08003c;
        public static final int abc_text_size_small_material=0x7f08003d;
        public static final int abc_text_size_subhead_material=0x7f08003e;
        public static final int abc_text_size_subtitle_material_toolbar=0x7f080003;
        public static final int abc_text_size_title_material=0x7f08003f;
        public static final int abc_text_size_title_material_toolbar=0x7f080004;
        public static final int dialog_fixed_height_major=0x7f080007;
        public static final int dialog_fixed_height_minor=0x7f080008;
        public static final int dialog_fixed_width_major=0x7f080009;
        public static final int dialog_fixed_width_minor=0x7f08000a;
        public static final int disabled_alpha_material_dark=0x7f080040;
        public static final int disabled_alpha_material_light=0x7f080041;
        public static final int highlight_alpha_material_colored=0x7f080042;
        public static final int highlight_alpha_material_dark=0x7f080043;
        public static final int highlight_alpha_material_light=0x7f080044;
        public static final int notification_large_icon_height=0x7f080045;
        public static final int notification_large_icon_width=0x7f080046;
        public static final int notification_subtext_size=0x7f080047;
    }
    public static final class drawable {
        public static final int abc_ab_share_pack_mtrl_alpha=0x7f020000;
        public static final int abc_action_bar_item_background_material=0x7f020001;
        public static final int abc_btn_borderless_material=0x7f020002;
        public static final int abc_btn_check_material=0x7f020003;
        public static final int abc_btn_check_to_on_mtrl_000=0x7f020004;
        public static final int abc_btn_check_to_on_mtrl_015=0x7f020005;
        public static final int abc_btn_colored_material=0x7f020006;
        public static final int abc_btn_default_mtrl_shape=0x7f020007;
        public static final int abc_btn_radio_material=0x7f020008;
        public static final int abc_btn_radio_to_on_mtrl_000=0x7f020009;
        public static final int abc_btn_radio_to_on_mtrl_015=0x7f02000a;
        public static final int abc_btn_rating_star_off_mtrl_alpha=0x7f02000b;
        public static final int abc_btn_rating_star_on_mtrl_alpha=0x7f02000c;
        public static final int abc_btn_switch_to_on_mtrl_00001=0x7f02000d;
        public static final int abc_btn_switch_to_on_mtrl_00012=0x7f02000e;
        public static final int abc_cab_background_internal_bg=0x7f02000f;
        public static final int abc_cab_background_top_material=0x7f020010;
        public static final int abc_cab_background_top_mtrl_alpha=0x7f020011;
        public static final int abc_control_background_material=0x7f020012;
        public static final int abc_dialog_material_background_dark=0x7f020013;
        public static final int abc_dialog_material_background_light=0x7f020014;
        public static final int abc_edit_text_material=0x7f020015;
        public static final int abc_ic_ab_back_mtrl_am_alpha=0x7f020016;
        public static final int abc_ic_clear_mtrl_alpha=0x7f020017;
        public static final int abc_ic_commit_search_api_mtrl_alpha=0x7f020018;
        public static final int abc_ic_go_search_api_mtrl_alpha=0x7f020019;
        public static final int abc_ic_menu_copy_mtrl_am_alpha=0x7f02001a;
        public static final int abc_ic_menu_cut_mtrl_alpha=0x7f02001b;
        public static final int abc_ic_menu_moreoverflow_mtrl_alpha=0x7f02001c;
        public static final int abc_ic_menu_paste_mtrl_am_alpha=0x7f02001d;
        public static final int abc_ic_menu_selectall_mtrl_alpha=0x7f02001e;
        public static final int abc_ic_menu_share_mtrl_alpha=0x7f02001f;
        public static final int abc_ic_search_api_mtrl_alpha=0x7f020020;
        public static final int abc_ic_voice_search_api_mtrl_alpha=0x7f020021;
        public static final int abc_item_background_holo_dark=0x7f020022;
        public static final int abc_item_background_holo_light=0x7f020023;
        public static final int abc_list_divider_mtrl_alpha=0x7f020024;
        public static final int abc_list_focused_holo=0x7f020025;
        public static final int abc_list_longpressed_holo=0x7f020026;
        public static final int abc_list_pressed_holo_dark=0x7f020027;
        public static final int abc_list_pressed_holo_light=0x7f020028;
        public static final int abc_list_selector_background_transition_holo_dark=0x7f020029;
        public static final int abc_list_selector_background_transition_holo_light=0x7f02002a;
        public static final int abc_list_selector_disabled_holo_dark=0x7f02002b;
        public static final int abc_list_selector_disabled_holo_light=0x7f02002c;
        public static final int abc_list_selector_holo_dark=0x7f02002d;
        public static final int abc_list_selector_holo_light=0x7f02002e;
        public static final int abc_menu_hardkey_panel_mtrl_mult=0x7f02002f;
        public static final int abc_popup_background_mtrl_mult=0x7f020030;
        public static final int abc_ratingbar_full_material=0x7f020031;
        public static final int abc_spinner_mtrl_am_alpha=0x7f020032;
        public static final int abc_spinner_textfield_background_material=0x7f020033;
        public static final int abc_switch_thumb_material=0x7f020034;
        public static final int abc_switch_track_mtrl_alpha=0x7f020035;
        public static final int abc_tab_indicator_material=0x7f020036;
        public static final int abc_tab_indicator_mtrl_alpha=0x7f020037;
        public static final int abc_text_cursor_material=0x7f020038;
        public static final int abc_textfield_activated_mtrl_alpha=0x7f020039;
        public static final int abc_textfield_default_mtrl_alpha=0x7f02003a;
        public static final int abc_textfield_search_activated_mtrl_alpha=0x7f02003b;
        public static final int abc_textfield_search_default_mtrl_alpha=0x7f02003c;
        public static final int abc_textfield_search_material=0x7f02003d;
        public static final int notification_template_icon_bg=0x7f02003e;
    }
    public static final class id {
        public static final int action0=0x7f0d0058;
        public static final int action_bar=0x7f0d0048;
        public static final int action_bar_activity_content=0x7f0d0000;
        public static final int action_bar_container=0x7f0d0047;
        public static final int action_bar_root=0x7f0d0043;
        public static final int action_bar_spinner=0x7f0d0001;
        public static final int action_bar_subtitle=0x7f0d002c;
        public static final int action_bar_title=0x7f0d002b;
        public static final int action_context_bar=0x7f0d0049;
        public static final int action_divider=0x7f0d005c;
        public static final int action_menu_divider=0x7f0d0002;
        public static final int action_menu_presenter=0x7f0d0003;
        public static final int action_mode_bar=0x7f0d0045;
        public static final int action_mode_bar_stub=0x7f0d0044;
        public static final int action_mode_close_button=0x7f0d002d;
        public static final int activity_chooser_view_content=0x7f0d002e;
        public static final int alertTitle=0x7f0d0038;
        public static final int always=0x7f0d0025;
        public static final int beginning=0x7f0d0022;
        public static final int buttonPanel=0x7f0d003e;
        public static final int cancel_action=0x7f0d0059;
        public static final int catalyst_redbox_title=0x7f0d0067;
        public static final int center=0x7f0d001a;
        public static final int centerCrop=0x7f0d001b;
        public static final int centerInside=0x7f0d001c;
        public static final int checkbox=0x7f0d0040;
        public static final int chronometer=0x7f0d005f;
        public static final int collapseActionView=0x7f0d0026;
        public static final int contentPanel=0x7f0d0039;
        public static final int custom=0x7f0d003d;
        public static final int customPanel=0x7f0d003c;
        public static final int decor_content_parent=0x7f0d0046;
        public static final int default_activity_button=0x7f0d0031;
        public static final int disableHome=0x7f0d000e;
        public static final int edit_query=0x7f0d004a;
        public static final int end=0x7f0d0023;
        public static final int end_padder=0x7f0d0064;
        public static final int expand_activities_button=0x7f0d002f;
        public static final int expanded_menu=0x7f0d003f;
        public static final int fitCenter=0x7f0d001d;
        public static final int fitEnd=0x7f0d001e;
        public static final int fitStart=0x7f0d001f;
        public static final int fitXY=0x7f0d0020;
        public static final int focusCrop=0x7f0d0021;
        public static final int fps_text=0x7f0d0057;
        public static final int home=0x7f0d0004;
        public static final int homeAsUp=0x7f0d000f;
        public static final int icon=0x7f0d0033;
        public static final int ifRoom=0x7f0d0027;
        public static final int image=0x7f0d0030;
        public static final int info=0x7f0d0063;
        public static final int line1=0x7f0d005d;
        public static final int line3=0x7f0d0061;
        public static final int listMode=0x7f0d000b;
        public static final int list_item=0x7f0d0032;
        public static final int media_actions=0x7f0d005b;
        public static final int middle=0x7f0d0024;
        public static final int multiply=0x7f0d0015;
        public static final int never=0x7f0d0028;
        public static final int none=0x7f0d0010;
        public static final int normal=0x7f0d000c;
        public static final int parentPanel=0x7f0d0035;
        public static final int progress_circular=0x7f0d0005;
        public static final int progress_horizontal=0x7f0d0006;
        public static final int radio=0x7f0d0042;
        public static final int react_test_id=0x7f0d0007;
        public static final int rn_frame_file=0x7f0d0066;
        public static final int rn_frame_method=0x7f0d0065;
        public static final int rn_redbox_copy_button=0x7f0d006e;
        public static final int rn_redbox_dismiss_button=0x7f0d006c;
        public static final int rn_redbox_line_separator=0x7f0d0069;
        public static final int rn_redbox_loading_indicator=0x7f0d006a;
        public static final int rn_redbox_reload_button=0x7f0d006d;
        public static final int rn_redbox_report_button=0x7f0d006f;
        public static final int rn_redbox_report_label=0x7f0d006b;
        public static final int rn_redbox_stack=0x7f0d0068;
        public static final int screen=0x7f0d0016;
        public static final int scrollView=0x7f0d003a;
        public static final int search_badge=0x7f0d004c;
        public static final int search_bar=0x7f0d004b;
        public static final int search_button=0x7f0d004d;
        public static final int search_close_btn=0x7f0d0052;
        public static final int search_edit_frame=0x7f0d004e;
        public static final int search_go_btn=0x7f0d0054;
        public static final int search_mag_icon=0x7f0d004f;
        public static final int search_plate=0x7f0d0050;
        public static final int search_src_text=0x7f0d0051;
        public static final int search_voice_btn=0x7f0d0055;
        public static final int select_dialog_listview=0x7f0d0056;
        public static final int shortcut=0x7f0d0041;
        public static final int showCustom=0x7f0d0011;
        public static final int showHome=0x7f0d0012;
        public static final int showTitle=0x7f0d0013;
        public static final int split_action_bar=0x7f0d0008;
        public static final int src_atop=0x7f0d0017;
        public static final int src_in=0x7f0d0018;
        public static final int src_over=0x7f0d0019;
        public static final int status_bar_latest_event_content=0x7f0d005a;
        public static final int submit_area=0x7f0d0053;
        public static final int tabMode=0x7f0d000d;
        public static final int text=0x7f0d0062;
        public static final int text2=0x7f0d0060;
        public static final int textSpacerNoButtons=0x7f0d003b;
        public static final int time=0x7f0d005e;
        public static final int title=0x7f0d0034;
        public static final int title_template=0x7f0d0037;
        public static final int topPanel=0x7f0d0036;
        public static final int up=0x7f0d0009;
        public static final int useLogo=0x7f0d0014;
        public static final int view_tag_native_id=0x7f0d000a;
        public static final int withText=0x7f0d0029;
        public static final int wrap_content=0x7f0d002a;
    }
    public static final class integer {
        public static final int abc_config_activityDefaultDur=0x7f0b0001;
        public static final int abc_config_activityShortDur=0x7f0b0002;
        public static final int abc_max_action_buttons=0x7f0b0000;
        public static final int cancel_button_image_alpha=0x7f0b0003;
        public static final int status_bar_notification_info_maxnum=0x7f0b0004;
    }
    public static final class layout {
        public static final int abc_action_bar_title_item=0x7f040000;
        public static final int abc_action_bar_up_container=0x7f040001;
        public static final int abc_action_bar_view_list_nav_layout=0x7f040002;
        public static final int abc_action_menu_item_layout=0x7f040003;
        public static final int abc_action_menu_layout=0x7f040004;
        public static final int abc_action_mode_bar=0x7f040005;
        public static final int abc_action_mode_close_item_material=0x7f040006;
        public static final int abc_activity_chooser_view=0x7f040007;
        public static final int abc_activity_chooser_view_list_item=0x7f040008;
        public static final int abc_alert_dialog_material=0x7f040009;
        public static final int abc_dialog_title_material=0x7f04000a;
        public static final int abc_expanded_menu_layout=0x7f04000b;
        public static final int abc_list_menu_item_checkbox=0x7f04000c;
        public static final int abc_list_menu_item_icon=0x7f04000d;
        public static final int abc_list_menu_item_layout=0x7f04000e;
        public static final int abc_list_menu_item_radio=0x7f04000f;
        public static final int abc_popup_menu_item_layout=0x7f040010;
        public static final int abc_screen_content_include=0x7f040011;
        public static final int abc_screen_simple=0x7f040012;
        public static final int abc_screen_simple_overlay_action_mode=0x7f040013;
        public static final int abc_screen_toolbar=0x7f040014;
        public static final int abc_search_dropdown_item_icons_2line=0x7f040015;
        public static final int abc_search_view=0x7f040016;
        public static final int abc_select_dialog_material=0x7f040017;
        public static final int dev_loading_view=0x7f040018;
        public static final int fps_view=0x7f040019;
        public static final int notification_media_action=0x7f04001a;
        public static final int notification_media_cancel_action=0x7f04001b;
        public static final int notification_template_big_media=0x7f04001c;
        public static final int notification_template_big_media_narrow=0x7f04001d;
        public static final int notification_template_lines=0x7f04001e;
        public static final int notification_template_media=0x7f04001f;
        public static final int notification_template_part_chronometer=0x7f040020;
        public static final int notification_template_part_time=0x7f040021;
        public static final int redbox_item_frame=0x7f040022;
        public static final int redbox_item_title=0x7f040023;
        public static final int redbox_view=0x7f040024;
        public static final int select_dialog_item_material=0x7f040025;
        public static final int select_dialog_multichoice_material=0x7f040026;
        public static final int select_dialog_singlechoice_material=0x7f040027;
        public static final int support_simple_spinner_dropdown_item=0x7f040028;
    }
    public static final class mipmap {
        public static final int ic_launcher=0x7f030000;
    }
    public static final class string {
        public static final int abc_action_bar_home_description=0x7f070000;
        public static final int abc_action_bar_home_description_format=0x7f070001;
        public static final int abc_action_bar_home_subtitle_description_format=0x7f070002;
        public static final int abc_action_bar_up_description=0x7f070003;
        public static final int abc_action_menu_overflow_description=0x7f070004;
        public static final int abc_action_mode_done=0x7f070005;
        public static final int abc_activity_chooser_view_see_all=0x7f070006;
        public static final int abc_activitychooserview_choose_application=0x7f070007;
        public static final int abc_search_hint=0x7f070008;
        public static final int abc_searchview_description_clear=0x7f070009;
        public static final int abc_searchview_description_query=0x7f07000a;
        public static final int abc_searchview_description_search=0x7f07000b;
        public static final int abc_searchview_description_submit=0x7f07000c;
        public static final int abc_searchview_description_voice=0x7f07000d;
        public static final int abc_shareactionprovider_share_with=0x7f07000e;
        public static final int abc_shareactionprovider_share_with_application=0x7f07000f;
        public static final int abc_toolbar_collapse_description=0x7f070010;
        public static final int app_name=0x7f070012;
        public static final int catalyst_copy_button=0x7f070013;
        public static final int catalyst_debugjs=0x7f070014;
        public static final int catalyst_debugjs_nuclide=0x7f070015;
        public static final int catalyst_debugjs_nuclide_failure=0x7f070016;
        public static final int catalyst_debugjs_off=0x7f070017;
        public static final int catalyst_dismiss_button=0x7f070018;
        public static final int catalyst_element_inspector=0x7f070019;
        public static final int catalyst_heap_capture=0x7f07001a;
        public static final int catalyst_hot_module_replacement=0x7f07001b;
        public static final int catalyst_hot_module_replacement_off=0x7f07001c;
        public static final int catalyst_jsload_error=0x7f07001d;
        public static final int catalyst_live_reload=0x7f07001e;
        public static final int catalyst_live_reload_off=0x7f07001f;
        public static final int catalyst_loading_from_url=0x7f070020;
        public static final int catalyst_perf_monitor=0x7f070021;
        public static final int catalyst_perf_monitor_off=0x7f070022;
        public static final int catalyst_poke_sampling_profiler=0x7f070023;
        public static final int catalyst_reload_button=0x7f070024;
        public static final int catalyst_reloadjs=0x7f070025;
        public static final int catalyst_remotedbg_error=0x7f070026;
        public static final int catalyst_remotedbg_message=0x7f070027;
        public static final int catalyst_report_button=0x7f070028;
        public static final int catalyst_settings=0x7f070029;
        public static final int catalyst_settings_title=0x7f07002a;
        public static final int status_bar_notification_info_overflow=0x7f070011;
    }
    public static final class style {
        public static final int AlertDialog_AppCompat=0x7f09007a;
        public static final int AlertDialog_AppCompat_Light=0x7f09007b;
        public static final int Animation_AppCompat_Dialog=0x7f09007c;
        public static final int Animation_AppCompat_DropDownUp=0x7f09007d;
        public static final int Animation_Catalyst_RedBox=0x7f09007e;
        /**  Customize your theme here. 
         */
        public static final int AppTheme=0x7f09007f;
        public static final int Base_AlertDialog_AppCompat=0x7f090080;
        public static final int Base_AlertDialog_AppCompat_Light=0x7f090081;
        public static final int Base_Animation_AppCompat_Dialog=0x7f090082;
        public static final int Base_Animation_AppCompat_DropDownUp=0x7f090083;
        public static final int Base_DialogWindowTitle_AppCompat=0x7f090084;
        public static final int Base_DialogWindowTitleBackground_AppCompat=0x7f090085;
        public static final int Base_TextAppearance_AppCompat=0x7f09002d;
        public static final int Base_TextAppearance_AppCompat_Body1=0x7f09002e;
        public static final int Base_TextAppearance_AppCompat_Body2=0x7f09002f;
        public static final int Base_TextAppearance_AppCompat_Button=0x7f090018;
        public static final int Base_TextAppearance_AppCompat_Caption=0x7f090030;
        public static final int Base_TextAppearance_AppCompat_Display1=0x7f090031;
        public static final int Base_TextAppearance_AppCompat_Display2=0x7f090032;
        public static final int Base_TextAppearance_AppCompat_Display3=0x7f090033;
        public static final int Base_TextAppearance_AppCompat_Display4=0x7f090034;
        public static final int Base_TextAppearance_AppCompat_Headline=0x7f090035;
        public static final int Base_TextAppearance_AppCompat_Inverse=0x7f090003;
        public static final int Base_TextAppearance_AppCompat_Large=0x7f090036;
        public static final int Base_TextAppearance_AppCompat_Large_Inverse=0x7f090004;
        public static final int Base_TextAppearance_AppCompat_Light_Widget_PopupMenu_Large=0x7f090037;
        public static final int Base_TextAppearance_AppCompat_Light_Widget_PopupMenu_Small=0x7f090038;
        public static final int Base_TextAppearance_AppCompat_Medium=0x7f090039;
        public static final int Base_TextAppearance_AppCompat_Medium_Inverse=0x7f090005;
        public static final int Base_TextAppearance_AppCompat_Menu=0x7f09003a;
        public static final int Base_TextAppearance_AppCompat_SearchResult=0x7f090086;
        public static final int Base_TextAppearance_AppCompat_SearchResult_Subtitle=0x7f09003b;
        public static final int Base_TextAppearance_AppCompat_SearchResult_Title=0x7f09003c;
        public static final int Base_TextAppearance_AppCompat_Small=0x7f09003d;
        public static final int Base_TextAppearance_AppCompat_Small_Inverse=0x7f090006;
        public static final int Base_TextAppearance_AppCompat_Subhead=0x7f09003e;
        public static final int Base_TextAppearance_AppCompat_Subhead_Inverse=0x7f090007;
        public static final int Base_TextAppearance_AppCompat_Title=0x7f09003f;
        public static final int Base_TextAppearance_AppCompat_Title_Inverse=0x7f090008;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionBar_Menu=0x7f090040;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionBar_Subtitle=0x7f090041;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionBar_Subtitle_Inverse=0x7f090042;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionBar_Title=0x7f090043;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionBar_Title_Inverse=0x7f090044;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionMode_Subtitle=0x7f090045;
        public static final int Base_TextAppearance_AppCompat_Widget_ActionMode_Title=0x7f090046;
        public static final int Base_TextAppearance_AppCompat_Widget_Button=0x7f090047;
        public static final int Base_TextAppearance_AppCompat_Widget_Button_Inverse=0x7f090076;
        public static final int Base_TextAppearance_AppCompat_Widget_DropDownItem=0x7f090087;
        public static final int Base_TextAppearance_AppCompat_Widget_PopupMenu_Large=0x7f090048;
        public static final int Base_TextAppearance_AppCompat_Widget_PopupMenu_Small=0x7f090049;
        public static final int Base_TextAppearance_AppCompat_Widget_Switch=0x7f09004a;
        public static final int Base_TextAppearance_AppCompat_Widget_TextView_SpinnerItem=0x7f09004b;
        public static final int Base_TextAppearance_Widget_AppCompat_ExpandedMenu_Item=0x7f090088;
        public static final int Base_TextAppearance_Widget_AppCompat_Toolbar_Subtitle=0x7f09004c;
        public static final int Base_TextAppearance_Widget_AppCompat_Toolbar_Title=0x7f09004d;
        public static final int Base_Theme_AppCompat=0x7f09004e;
        public static final int Base_Theme_AppCompat_CompactMenu=0x7f090089;
        public static final int Base_Theme_AppCompat_Dialog=0x7f090009;
        public static final int Base_Theme_AppCompat_Dialog_Alert=0x7f09008a;
        public static final int Base_Theme_AppCompat_Dialog_FixedSize=0x7f09008b;
        public static final int Base_Theme_AppCompat_Dialog_MinWidth=0x7f09008c;
        public static final int Base_Theme_AppCompat_DialogWhenLarge=0x7f090001;
        public static final int Base_Theme_AppCompat_Light=0x7f09004f;
        public static final int Base_Theme_AppCompat_Light_DarkActionBar=0x7f09008d;
        public static final int Base_Theme_AppCompat_Light_Dialog=0x7f09000a;
        public static final int Base_Theme_AppCompat_Light_Dialog_Alert=0x7f09008e;
        public static final int Base_Theme_AppCompat_Light_Dialog_FixedSize=0x7f09008f;
        public static final int Base_Theme_AppCompat_Light_Dialog_MinWidth=0x7f090090;
        public static final int Base_Theme_AppCompat_Light_DialogWhenLarge=0x7f090002;
        public static final int Base_ThemeOverlay_AppCompat=0x7f090091;
        public static final int Base_ThemeOverlay_AppCompat_ActionBar=0x7f090092;
        public static final int Base_ThemeOverlay_AppCompat_Dark=0x7f090093;
        public static final int Base_ThemeOverlay_AppCompat_Dark_ActionBar=0x7f090094;
        public static final int Base_ThemeOverlay_AppCompat_Light=0x7f090095;
        public static final int Base_V11_Theme_AppCompat_Dialog=0x7f09000b;
        public static final int Base_V11_Theme_AppCompat_Light_Dialog=0x7f09000c;
        public static final int Base_V12_Widget_AppCompat_AutoCompleteTextView=0x7f090014;
        public static final int Base_V12_Widget_AppCompat_EditText=0x7f090015;
        public static final int Base_V21_Theme_AppCompat=0x7f090050;
        public static final int Base_V21_Theme_AppCompat_Dialog=0x7f090051;
        public static final int Base_V21_Theme_AppCompat_Light=0x7f090052;
        public static final int Base_V21_Theme_AppCompat_Light_Dialog=0x7f090053;
        public static final int Base_V22_Theme_AppCompat=0x7f090074;
        public static final int Base_V22_Theme_AppCompat_Light=0x7f090075;
        public static final int Base_V23_Theme_AppCompat=0x7f090077;
        public static final int Base_V23_Theme_AppCompat_Light=0x7f090078;
        public static final int Base_V7_Theme_AppCompat=0x7f090096;
        public static final int Base_V7_Theme_AppCompat_Dialog=0x7f090097;
        public static final int Base_V7_Theme_AppCompat_Light=0x7f090098;
        public static final int Base_V7_Theme_AppCompat_Light_Dialog=0x7f090099;
        public static final int Base_V7_Widget_AppCompat_AutoCompleteTextView=0x7f09009a;
        public static final int Base_V7_Widget_AppCompat_EditText=0x7f09009b;
        public static final int Base_Widget_AppCompat_ActionBar=0x7f09009c;
        public static final int Base_Widget_AppCompat_ActionBar_Solid=0x7f09009d;
        public static final int Base_Widget_AppCompat_ActionBar_TabBar=0x7f09009e;
        public static final int Base_Widget_AppCompat_ActionBar_TabText=0x7f090054;
        public static final int Base_Widget_AppCompat_ActionBar_TabView=0x7f090055;
        public static final int Base_Widget_AppCompat_ActionButton=0x7f090056;
        public static final int Base_Widget_AppCompat_ActionButton_CloseMode=0x7f090057;
        public static final int Base_Widget_AppCompat_ActionButton_Overflow=0x7f090058;
        public static final int Base_Widget_AppCompat_ActionMode=0x7f09009f;
        public static final int Base_Widget_AppCompat_ActivityChooserView=0x7f0900a0;
        public static final int Base_Widget_AppCompat_AutoCompleteTextView=0x7f090016;
        public static final int Base_Widget_AppCompat_Button=0x7f090059;
        public static final int Base_Widget_AppCompat_Button_Borderless=0x7f09005a;
        public static final int Base_Widget_AppCompat_Button_Borderless_Colored=0x7f09005b;
        public static final int Base_Widget_AppCompat_Button_ButtonBar_AlertDialog=0x7f0900a1;
        public static final int Base_Widget_AppCompat_Button_Colored=0x7f090079;
        public static final int Base_Widget_AppCompat_Button_Small=0x7f09005c;
        public static final int Base_Widget_AppCompat_ButtonBar=0x7f09005d;
        public static final int Base_Widget_AppCompat_ButtonBar_AlertDialog=0x7f0900a2;
        public static final int Base_Widget_AppCompat_CompoundButton_CheckBox=0x7f09005e;
        public static final int Base_Widget_AppCompat_CompoundButton_RadioButton=0x7f09005f;
        public static final int Base_Widget_AppCompat_CompoundButton_Switch=0x7f0900a3;
        public static final int Base_Widget_AppCompat_DrawerArrowToggle=0x7f090000;
        public static final int Base_Widget_AppCompat_DrawerArrowToggle_Common=0x7f0900a4;
        public static final int Base_Widget_AppCompat_DropDownItem_Spinner=0x7f090060;
        public static final int Base_Widget_AppCompat_EditText=0x7f090017;
        public static final int Base_Widget_AppCompat_Light_ActionBar=0x7f0900a5;
        public static final int Base_Widget_AppCompat_Light_ActionBar_Solid=0x7f0900a6;
        public static final int Base_Widget_AppCompat_Light_ActionBar_TabBar=0x7f0900a7;
        public static final int Base_Widget_AppCompat_Light_ActionBar_TabText=0x7f090061;
        public static final int Base_Widget_AppCompat_Light_ActionBar_TabText_Inverse=0x7f090062;
        public static final int Base_Widget_AppCompat_Light_ActionBar_TabView=0x7f090063;
        public static final int Base_Widget_AppCompat_Light_PopupMenu=0x7f090064;
        public static final int Base_Widget_AppCompat_Light_PopupMenu_Overflow=0x7f090065;
        public static final int Base_Widget_AppCompat_ListPopupWindow=0x7f090066;
        public static final int Base_Widget_AppCompat_ListView=0x7f090067;
        public static final int Base_Widget_AppCompat_ListView_DropDown=0x7f090068;
        public static final int Base_Widget_AppCompat_ListView_Menu=0x7f090069;
        public static final int Base_Widget_AppCompat_PopupMenu=0x7f09006a;
        public static final int Base_Widget_AppCompat_PopupMenu_Overflow=0x7f09006b;
        public static final int Base_Widget_AppCompat_PopupWindow=0x7f0900a8;
        public static final int Base_Widget_AppCompat_ProgressBar=0x7f09000d;
        public static final int Base_Widget_AppCompat_ProgressBar_Horizontal=0x7f09000e;
        public static final int Base_Widget_AppCompat_RatingBar=0x7f09006c;
        public static final int Base_Widget_AppCompat_SearchView=0x7f0900a9;
        public static final int Base_Widget_AppCompat_SearchView_ActionBar=0x7f0900aa;
        public static final int Base_Widget_AppCompat_Spinner=0x7f09006d;
        public static final int Base_Widget_AppCompat_Spinner_Underlined=0x7f09006e;
        public static final int Base_Widget_AppCompat_TextView_SpinnerItem=0x7f09006f;
        public static final int Base_Widget_AppCompat_Toolbar=0x7f0900ab;
        public static final int Base_Widget_AppCompat_Toolbar_Button_Navigation=0x7f090070;
        public static final int CalendarDatePickerDialog=0x7f0900ac;
        public static final int CalendarDatePickerStyle=0x7f0900ad;
        public static final int ClockTimePickerDialog=0x7f0900ae;
        public static final int ClockTimePickerStyle=0x7f0900af;
        public static final int DialogAnimationFade=0x7f0900b0;
        public static final int DialogAnimationSlide=0x7f0900b1;
        public static final int Platform_AppCompat=0x7f09000f;
        public static final int Platform_AppCompat_Light=0x7f090010;
        public static final int Platform_ThemeOverlay_AppCompat=0x7f090071;
        public static final int Platform_ThemeOverlay_AppCompat_Dark=0x7f090072;
        public static final int Platform_ThemeOverlay_AppCompat_Light=0x7f090073;
        public static final int Platform_V11_AppCompat=0x7f090011;
        public static final int Platform_V11_AppCompat_Light=0x7f090012;
        public static final int Platform_V14_AppCompat=0x7f090019;
        public static final int Platform_V14_AppCompat_Light=0x7f09001a;
        public static final int Platform_Widget_AppCompat_Spinner=0x7f090013;
        public static final int RtlOverlay_DialogWindowTitle_AppCompat=0x7f090020;
        public static final int RtlOverlay_Widget_AppCompat_ActionBar_TitleItem=0x7f090021;
        public static final int RtlOverlay_Widget_AppCompat_ActionButton_Overflow=0x7f090022;
        public static final int RtlOverlay_Widget_AppCompat_DialogTitle_Icon=0x7f090023;
        public static final int RtlOverlay_Widget_AppCompat_PopupMenuItem=0x7f090024;
        public static final int RtlOverlay_Widget_AppCompat_PopupMenuItem_InternalGroup=0x7f090025;
        public static final int RtlOverlay_Widget_AppCompat_PopupMenuItem_Text=0x7f090026;
        public static final int RtlOverlay_Widget_AppCompat_Search_DropDown=0x7f090027;
        public static final int RtlOverlay_Widget_AppCompat_Search_DropDown_Icon1=0x7f090028;
        public static final int RtlOverlay_Widget_AppCompat_Search_DropDown_Icon2=0x7f090029;
        public static final int RtlOverlay_Widget_AppCompat_Search_DropDown_Query=0x7f09002a;
        public static final int RtlOverlay_Widget_AppCompat_Search_DropDown_Text=0x7f09002b;
        public static final int RtlOverlay_Widget_AppCompat_SearchView_MagIcon=0x7f09002c;
        public static final int SpinnerDatePickerDialog=0x7f0900b2;
        public static final int SpinnerDatePickerStyle=0x7f0900b3;
        public static final int SpinnerTimePickerDialog=0x7f0900b4;
        public static final int SpinnerTimePickerStyle=0x7f0900b5;
        public static final int TextAppearance_AppCompat=0x7f0900b6;
        public static final int TextAppearance_AppCompat_Body1=0x7f0900b7;
        public static final int TextAppearance_AppCompat_Body2=0x7f0900b8;
        public static final int TextAppearance_AppCompat_Button=0x7f0900b9;
        public static final int TextAppearance_AppCompat_Caption=0x7f0900ba;
        public static final int TextAppearance_AppCompat_Display1=0x7f0900bb;
        public static final int TextAppearance_AppCompat_Display2=0x7f0900bc;
        public static final int TextAppearance_AppCompat_Display3=0x7f0900bd;
        public static final int TextAppearance_AppCompat_Display4=0x7f0900be;
        public static final int TextAppearance_AppCompat_Headline=0x7f0900bf;
        public static final int TextAppearance_AppCompat_Inverse=0x7f0900c0;
        public static final int TextAppearance_AppCompat_Large=0x7f0900c1;
        public static final int TextAppearance_AppCompat_Large_Inverse=0x7f0900c2;
        public static final int TextAppearance_AppCompat_Light_SearchResult_Subtitle=0x7f0900c3;
        public static final int TextAppearance_AppCompat_Light_SearchResult_Title=0x7f0900c4;
        public static final int TextAppearance_AppCompat_Light_Widget_PopupMenu_Large=0x7f0900c5;
        public static final int TextAppearance_AppCompat_Light_Widget_PopupMenu_Small=0x7f0900c6;
        public static final int TextAppearance_AppCompat_Medium=0x7f0900c7;
        public static final int TextAppearance_AppCompat_Medium_Inverse=0x7f0900c8;
        public static final int TextAppearance_AppCompat_Menu=0x7f0900c9;
        public static final int TextAppearance_AppCompat_SearchResult_Subtitle=0x7f0900ca;
        public static final int TextAppearance_AppCompat_SearchResult_Title=0x7f0900cb;
        public static final int TextAppearance_AppCompat_Small=0x7f0900cc;
        public static final int TextAppearance_AppCompat_Small_Inverse=0x7f0900cd;
        public static final int TextAppearance_AppCompat_Subhead=0x7f0900ce;
        public static final int TextAppearance_AppCompat_Subhead_Inverse=0x7f0900cf;
        public static final int TextAppearance_AppCompat_Title=0x7f0900d0;
        public static final int TextAppearance_AppCompat_Title_Inverse=0x7f0900d1;
        public static final int TextAppearance_AppCompat_Widget_ActionBar_Menu=0x7f0900d2;
        public static final int TextAppearance_AppCompat_Widget_ActionBar_Subtitle=0x7f0900d3;
        public static final int TextAppearance_AppCompat_Widget_ActionBar_Subtitle_Inverse=0x7f0900d4;
        public static final int TextAppearance_AppCompat_Widget_ActionBar_Title=0x7f0900d5;
        public static final int TextAppearance_AppCompat_Widget_ActionBar_Title_Inverse=0x7f0900d6;
        public static final int TextAppearance_AppCompat_Widget_ActionMode_Subtitle=0x7f0900d7;
        public static final int TextAppearance_AppCompat_Widget_ActionMode_Subtitle_Inverse=0x7f0900d8;
        public static final int TextAppearance_AppCompat_Widget_ActionMode_Title=0x7f0900d9;
        public static final int TextAppearance_AppCompat_Widget_ActionMode_Title_Inverse=0x7f0900da;
        public static final int TextAppearance_AppCompat_Widget_Button=0x7f0900db;
        public static final int TextAppearance_AppCompat_Widget_Button_Inverse=0x7f0900dc;
        public static final int TextAppearance_AppCompat_Widget_DropDownItem=0x7f0900dd;
        public static final int TextAppearance_AppCompat_Widget_PopupMenu_Large=0x7f0900de;
        public static final int TextAppearance_AppCompat_Widget_PopupMenu_Small=0x7f0900df;
        public static final int TextAppearance_AppCompat_Widget_Switch=0x7f0900e0;
        public static final int TextAppearance_AppCompat_Widget_TextView_SpinnerItem=0x7f0900e1;
        public static final int TextAppearance_StatusBar_EventContent=0x7f09001b;
        public static final int TextAppearance_StatusBar_EventContent_Info=0x7f09001c;
        public static final int TextAppearance_StatusBar_EventContent_Line2=0x7f09001d;
        public static final int TextAppearance_StatusBar_EventContent_Time=0x7f09001e;
        public static final int TextAppearance_StatusBar_EventContent_Title=0x7f09001f;
        public static final int TextAppearance_Widget_AppCompat_ExpandedMenu_Item=0x7f0900e2;
        public static final int TextAppearance_Widget_AppCompat_Toolbar_Subtitle=0x7f0900e3;
        public static final int TextAppearance_Widget_AppCompat_Toolbar_Title=0x7f0900e4;
        public static final int Theme=0x7f0900e5;
        public static final int Theme_AppCompat=0x7f0900e6;
        public static final int Theme_AppCompat_CompactMenu=0x7f0900e7;
        public static final int Theme_AppCompat_Dialog=0x7f0900e8;
        public static final int Theme_AppCompat_Dialog_Alert=0x7f0900e9;
        public static final int Theme_AppCompat_Dialog_MinWidth=0x7f0900ea;
        public static final int Theme_AppCompat_DialogWhenLarge=0x7f0900eb;
        public static final int Theme_AppCompat_Light=0x7f0900ec;
        public static final int Theme_AppCompat_Light_DarkActionBar=0x7f0900ed;
        public static final int Theme_AppCompat_Light_Dialog=0x7f0900ee;
        public static final int Theme_AppCompat_Light_Dialog_Alert=0x7f0900ef;
        public static final int Theme_AppCompat_Light_Dialog_MinWidth=0x7f0900f0;
        public static final int Theme_AppCompat_Light_DialogWhenLarge=0x7f0900f1;
        public static final int Theme_AppCompat_Light_NoActionBar=0x7f0900f2;
        public static final int Theme_AppCompat_NoActionBar=0x7f0900f3;
        public static final int Theme_Catalyst=0x7f0900f4;
        public static final int Theme_Catalyst_RedBox=0x7f0900f5;
        public static final int Theme_FullScreenDialog=0x7f0900f6;
        public static final int Theme_FullScreenDialogAnimatedFade=0x7f0900f7;
        public static final int Theme_FullScreenDialogAnimatedSlide=0x7f0900f8;
        public static final int Theme_ReactNative_AppCompat_Light=0x7f0900f9;
        public static final int Theme_ReactNative_AppCompat_Light_NoActionBar_FullScreen=0x7f0900fa;
        public static final int ThemeOverlay_AppCompat=0x7f0900fb;
        public static final int ThemeOverlay_AppCompat_ActionBar=0x7f0900fc;
        public static final int ThemeOverlay_AppCompat_Dark=0x7f0900fd;
        public static final int ThemeOverlay_AppCompat_Dark_ActionBar=0x7f0900fe;
        public static final int ThemeOverlay_AppCompat_Light=0x7f0900ff;
        public static final int Widget_AppCompat_ActionBar=0x7f090100;
        public static final int Widget_AppCompat_ActionBar_Solid=0x7f090101;
        public static final int Widget_AppCompat_ActionBar_TabBar=0x7f090102;
        public static final int Widget_AppCompat_ActionBar_TabText=0x7f090103;
        public static final int Widget_AppCompat_ActionBar_TabView=0x7f090104;
        public static final int Widget_AppCompat_ActionButton=0x7f090105;
        public static final int Widget_AppCompat_ActionButton_CloseMode=0x7f090106;
        public static final int Widget_AppCompat_ActionButton_Overflow=0x7f090107;
        public static final int Widget_AppCompat_ActionMode=0x7f090108;
        public static final int Widget_AppCompat_ActivityChooserView=0x7f090109;
        public static final int Widget_AppCompat_AutoCompleteTextView=0x7f09010a;
        public static final int Widget_AppCompat_Button=0x7f09010b;
        public static final int Widget_AppCompat_Button_Borderless=0x7f09010c;
        public static final int Widget_AppCompat_Button_Borderless_Colored=0x7f09010d;
        public static final int Widget_AppCompat_Button_ButtonBar_AlertDialog=0x7f09010e;
        public static final int Widget_AppCompat_Button_Colored=0x7f09010f;
        public static final int Widget_AppCompat_Button_Small=0x7f090110;
        public static final int Widget_AppCompat_ButtonBar=0x7f090111;
        public static final int Widget_AppCompat_ButtonBar_AlertDialog=0x7f090112;
        public static final int Widget_AppCompat_CompoundButton_CheckBox=0x7f090113;
        public static final int Widget_AppCompat_CompoundButton_RadioButton=0x7f090114;
        public static final int Widget_AppCompat_CompoundButton_Switch=0x7f090115;
        public static final int Widget_AppCompat_DrawerArrowToggle=0x7f090116;
        public static final int Widget_AppCompat_DropDownItem_Spinner=0x7f090117;
        public static final int Widget_AppCompat_EditText=0x7f090118;
        public static final int Widget_AppCompat_Light_ActionBar=0x7f090119;
        public static final int Widget_AppCompat_Light_ActionBar_Solid=0x7f09011a;
        public static final int Widget_AppCompat_Light_ActionBar_Solid_Inverse=0x7f09011b;
        public static final int Widget_AppCompat_Light_ActionBar_TabBar=0x7f09011c;
        public static final int Widget_AppCompat_Light_ActionBar_TabBar_Inverse=0x7f09011d;
        public static final int Widget_AppCompat_Light_ActionBar_TabText=0x7f09011e;
        public static final int Widget_AppCompat_Light_ActionBar_TabText_Inverse=0x7f09011f;
        public static final int Widget_AppCompat_Light_ActionBar_TabView=0x7f090120;
        public static final int Widget_AppCompat_Light_ActionBar_TabView_Inverse=0x7f090121;
        public static final int Widget_AppCompat_Light_ActionButton=0x7f090122;
        public static final int Widget_AppCompat_Light_ActionButton_CloseMode=0x7f090123;
        public static final int Widget_AppCompat_Light_ActionButton_Overflow=0x7f090124;
        public static final int Widget_AppCompat_Light_ActionMode_Inverse=0x7f090125;
        public static final int Widget_AppCompat_Light_ActivityChooserView=0x7f090126;
        public static final int Widget_AppCompat_Light_AutoCompleteTextView=0x7f090127;
        public static final int Widget_AppCompat_Light_DropDownItem_Spinner=0x7f090128;
        public static final int Widget_AppCompat_Light_ListPopupWindow=0x7f090129;
        public static final int Widget_AppCompat_Light_ListView_DropDown=0x7f09012a;
        public static final int Widget_AppCompat_Light_PopupMenu=0x7f09012b;
        public static final int Widget_AppCompat_Light_PopupMenu_Overflow=0x7f09012c;
        public static final int Widget_AppCompat_Light_SearchView=0x7f09012d;
        public static final int Widget_AppCompat_Light_Spinner_DropDown_ActionBar=0x7f09012e;
        public static final int Widget_AppCompat_ListPopupWindow=0x7f09012f;
        public static final int Widget_AppCompat_ListView=0x7f090130;
        public static final int Widget_AppCompat_ListView_DropDown=0x7f090131;
        public static final int Widget_AppCompat_ListView_Menu=0x7f090132;
        public static final int Widget_AppCompat_PopupMenu=0x7f090133;
        public static final int Widget_AppCompat_PopupMenu_Overflow=0x7f090134;
        public static final int Widget_AppCompat_PopupWindow=0x7f090135;
        public static final int Widget_AppCompat_ProgressBar=0x7f090136;
        public static final int Widget_AppCompat_ProgressBar_Horizontal=0x7f090137;
        public static final int Widget_AppCompat_RatingBar=0x7f090138;
        public static final int Widget_AppCompat_SearchView=0x7f090139;
        public static final int Widget_AppCompat_SearchView_ActionBar=0x7f09013a;
        public static final int Widget_AppCompat_Spinner=0x7f09013b;
        public static final int Widget_AppCompat_Spinner_DropDown=0x7f09013c;
        public static final int Widget_AppCompat_Spinner_DropDown_ActionBar=0x7f09013d;
        public static final int Widget_AppCompat_Spinner_Underlined=0x7f09013e;
        public static final int Widget_AppCompat_TextView_SpinnerItem=0x7f09013f;
        public static final int Widget_AppCompat_Toolbar=0x7f090140;
        public static final int Widget_AppCompat_Toolbar_Button_Navigation=0x7f090141;
        public static final int redboxButton=0x7f090142;
    }
    public static final class xml {
        public static final int preferences=0x7f060000;
    }
    public static final class styleable {
        /** Attributes that can be used with a ActionBar.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionBar_background com.revenuecat.purchases_sample:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_backgroundSplit com.revenuecat.purchases_sample:backgroundSplit}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_backgroundStacked com.revenuecat.purchases_sample:backgroundStacked}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetEnd com.revenuecat.purchases_sample:contentInsetEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetLeft com.revenuecat.purchases_sample:contentInsetLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetRight com.revenuecat.purchases_sample:contentInsetRight}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetStart com.revenuecat.purchases_sample:contentInsetStart}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_customNavigationLayout com.revenuecat.purchases_sample:customNavigationLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_displayOptions com.revenuecat.purchases_sample:displayOptions}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_divider com.revenuecat.purchases_sample:divider}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_elevation com.revenuecat.purchases_sample:elevation}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_height com.revenuecat.purchases_sample:height}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_hideOnContentScroll com.revenuecat.purchases_sample:hideOnContentScroll}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_homeAsUpIndicator com.revenuecat.purchases_sample:homeAsUpIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_homeLayout com.revenuecat.purchases_sample:homeLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_icon com.revenuecat.purchases_sample:icon}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_indeterminateProgressStyle com.revenuecat.purchases_sample:indeterminateProgressStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_itemPadding com.revenuecat.purchases_sample:itemPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_logo com.revenuecat.purchases_sample:logo}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_navigationMode com.revenuecat.purchases_sample:navigationMode}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_popupTheme com.revenuecat.purchases_sample:popupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_progressBarPadding com.revenuecat.purchases_sample:progressBarPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_progressBarStyle com.revenuecat.purchases_sample:progressBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_subtitle com.revenuecat.purchases_sample:subtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_subtitleTextStyle com.revenuecat.purchases_sample:subtitleTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_title com.revenuecat.purchases_sample:title}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_titleTextStyle com.revenuecat.purchases_sample:titleTextStyle}</code></td><td></td></tr>
           </table>
           @see #ActionBar_background
           @see #ActionBar_backgroundSplit
           @see #ActionBar_backgroundStacked
           @see #ActionBar_contentInsetEnd
           @see #ActionBar_contentInsetLeft
           @see #ActionBar_contentInsetRight
           @see #ActionBar_contentInsetStart
           @see #ActionBar_customNavigationLayout
           @see #ActionBar_displayOptions
           @see #ActionBar_divider
           @see #ActionBar_elevation
           @see #ActionBar_height
           @see #ActionBar_hideOnContentScroll
           @see #ActionBar_homeAsUpIndicator
           @see #ActionBar_homeLayout
           @see #ActionBar_icon
           @see #ActionBar_indeterminateProgressStyle
           @see #ActionBar_itemPadding
           @see #ActionBar_logo
           @see #ActionBar_navigationMode
           @see #ActionBar_popupTheme
           @see #ActionBar_progressBarPadding
           @see #ActionBar_progressBarStyle
           @see #ActionBar_subtitle
           @see #ActionBar_subtitleTextStyle
           @see #ActionBar_title
           @see #ActionBar_titleTextStyle
         */
        public static final int[] ActionBar = {
            0x7f010001, 0x7f010003, 0x7f010004, 0x7f010005,
            0x7f010006, 0x7f010007, 0x7f010008, 0x7f010009,
            0x7f01000a, 0x7f01000b, 0x7f01000c, 0x7f01000d,
            0x7f01000e, 0x7f01000f, 0x7f010010, 0x7f010011,
            0x7f010012, 0x7f010013, 0x7f010014, 0x7f010015,
            0x7f010016, 0x7f010017, 0x7f010018, 0x7f010019,
            0x7f01001a, 0x7f01001b, 0x7f010096
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#background}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:background
        */
        public static final int ActionBar_background = 10;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundSplit}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:backgroundSplit
        */
        public static final int ActionBar_backgroundSplit = 12;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundStacked}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:backgroundStacked
        */
        public static final int ActionBar_backgroundStacked = 11;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetEnd}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetEnd
        */
        public static final int ActionBar_contentInsetEnd = 21;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetLeft}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetLeft
        */
        public static final int ActionBar_contentInsetLeft = 22;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetRight}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetRight
        */
        public static final int ActionBar_contentInsetRight = 23;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetStart}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetStart
        */
        public static final int ActionBar_contentInsetStart = 20;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#customNavigationLayout}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:customNavigationLayout
        */
        public static final int ActionBar_customNavigationLayout = 13;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#displayOptions}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>useLogo</code></td><td>0x1</td><td></td></tr>
<tr><td><code>showHome</code></td><td>0x2</td><td></td></tr>
<tr><td><code>homeAsUp</code></td><td>0x4</td><td></td></tr>
<tr><td><code>showTitle</code></td><td>0x8</td><td></td></tr>
<tr><td><code>showCustom</code></td><td>0x10</td><td></td></tr>
<tr><td><code>disableHome</code></td><td>0x20</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:displayOptions
        */
        public static final int ActionBar_displayOptions = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#divider}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:divider
        */
        public static final int ActionBar_divider = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#elevation}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:elevation
        */
        public static final int ActionBar_elevation = 24;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#height}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:height
        */
        public static final int ActionBar_height = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#hideOnContentScroll}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:hideOnContentScroll
        */
        public static final int ActionBar_hideOnContentScroll = 19;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#homeAsUpIndicator}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:homeAsUpIndicator
        */
        public static final int ActionBar_homeAsUpIndicator = 26;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#homeLayout}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:homeLayout
        */
        public static final int ActionBar_homeLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#icon}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:icon
        */
        public static final int ActionBar_icon = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#indeterminateProgressStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:indeterminateProgressStyle
        */
        public static final int ActionBar_indeterminateProgressStyle = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#itemPadding}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:itemPadding
        */
        public static final int ActionBar_itemPadding = 18;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#logo}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:logo
        */
        public static final int ActionBar_logo = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#navigationMode}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>normal</code></td><td>0</td><td></td></tr>
<tr><td><code>listMode</code></td><td>1</td><td></td></tr>
<tr><td><code>tabMode</code></td><td>2</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:navigationMode
        */
        public static final int ActionBar_navigationMode = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#popupTheme}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:popupTheme
        */
        public static final int ActionBar_popupTheme = 25;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#progressBarPadding}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:progressBarPadding
        */
        public static final int ActionBar_progressBarPadding = 17;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#progressBarStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:progressBarStyle
        */
        public static final int ActionBar_progressBarStyle = 15;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:subtitle
        */
        public static final int ActionBar_subtitle = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitleTextStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:subtitleTextStyle
        */
        public static final int ActionBar_subtitleTextStyle = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#title}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:title
        */
        public static final int ActionBar_title = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleTextStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:titleTextStyle
        */
        public static final int ActionBar_titleTextStyle = 5;
        /** Attributes that can be used with a ActionBarLayout.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionBarLayout_android_layout_gravity android:layout_gravity}</code></td><td></td></tr>
           </table>
           @see #ActionBarLayout_android_layout_gravity
         */
        public static final int[] ActionBarLayout = {
            0x010100b3
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_gravity}
          attribute's value can be found in the {@link #ActionBarLayout} array.
          @attr name android:layout_gravity
        */
        public static final int ActionBarLayout_android_layout_gravity = 0;
        /** Attributes that can be used with a ActionMenuItemView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionMenuItemView_android_minWidth android:minWidth}</code></td><td></td></tr>
           </table>
           @see #ActionMenuItemView_android_minWidth
         */
        public static final int[] ActionMenuItemView = {
            0x0101013f
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#minWidth}
          attribute's value can be found in the {@link #ActionMenuItemView} array.
          @attr name android:minWidth
        */
        public static final int ActionMenuItemView_android_minWidth = 0;
        /** Attributes that can be used with a ActionMenuView.
         */
        public static final int[] ActionMenuView = {
            
        };
        /** Attributes that can be used with a ActionMode.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionMode_background com.revenuecat.purchases_sample:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_backgroundSplit com.revenuecat.purchases_sample:backgroundSplit}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_closeItemLayout com.revenuecat.purchases_sample:closeItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_height com.revenuecat.purchases_sample:height}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_subtitleTextStyle com.revenuecat.purchases_sample:subtitleTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_titleTextStyle com.revenuecat.purchases_sample:titleTextStyle}</code></td><td></td></tr>
           </table>
           @see #ActionMode_background
           @see #ActionMode_backgroundSplit
           @see #ActionMode_closeItemLayout
           @see #ActionMode_height
           @see #ActionMode_subtitleTextStyle
           @see #ActionMode_titleTextStyle
         */
        public static final int[] ActionMode = {
            0x7f010001, 0x7f010007, 0x7f010008, 0x7f01000c,
            0x7f01000e, 0x7f01001c
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#background}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:background
        */
        public static final int ActionMode_background = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundSplit}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:backgroundSplit
        */
        public static final int ActionMode_backgroundSplit = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#closeItemLayout}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:closeItemLayout
        */
        public static final int ActionMode_closeItemLayout = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#height}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:height
        */
        public static final int ActionMode_height = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitleTextStyle}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:subtitleTextStyle
        */
        public static final int ActionMode_subtitleTextStyle = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleTextStyle}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:titleTextStyle
        */
        public static final int ActionMode_titleTextStyle = 1;
        /** Attributes that can be used with a ActivityChooserView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActivityChooserView_expandActivityOverflowButtonDrawable com.revenuecat.purchases_sample:expandActivityOverflowButtonDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #ActivityChooserView_initialActivityCount com.revenuecat.purchases_sample:initialActivityCount}</code></td><td></td></tr>
           </table>
           @see #ActivityChooserView_expandActivityOverflowButtonDrawable
           @see #ActivityChooserView_initialActivityCount
         */
        public static final int[] ActivityChooserView = {
            0x7f01001d, 0x7f01001e
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#expandActivityOverflowButtonDrawable}
          attribute's value can be found in the {@link #ActivityChooserView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:expandActivityOverflowButtonDrawable
        */
        public static final int ActivityChooserView_expandActivityOverflowButtonDrawable = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#initialActivityCount}
          attribute's value can be found in the {@link #ActivityChooserView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:initialActivityCount
        */
        public static final int ActivityChooserView_initialActivityCount = 0;
        /** Attributes that can be used with a AlertDialog.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #AlertDialog_android_layout android:layout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_buttonPanelSideLayout com.revenuecat.purchases_sample:buttonPanelSideLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_listItemLayout com.revenuecat.purchases_sample:listItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_listLayout com.revenuecat.purchases_sample:listLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_multiChoiceItemLayout com.revenuecat.purchases_sample:multiChoiceItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_singleChoiceItemLayout com.revenuecat.purchases_sample:singleChoiceItemLayout}</code></td><td></td></tr>
           </table>
           @see #AlertDialog_android_layout
           @see #AlertDialog_buttonPanelSideLayout
           @see #AlertDialog_listItemLayout
           @see #AlertDialog_listLayout
           @see #AlertDialog_multiChoiceItemLayout
           @see #AlertDialog_singleChoiceItemLayout
         */
        public static final int[] AlertDialog = {
            0x010100f2, 0x7f01001f, 0x7f010020, 0x7f010021,
            0x7f010022, 0x7f010023
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout}
          attribute's value can be found in the {@link #AlertDialog} array.
          @attr name android:layout
        */
        public static final int AlertDialog_android_layout = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonPanelSideLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonPanelSideLayout
        */
        public static final int AlertDialog_buttonPanelSideLayout = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:listItemLayout
        */
        public static final int AlertDialog_listItemLayout = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:listLayout
        */
        public static final int AlertDialog_listLayout = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#multiChoiceItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:multiChoiceItemLayout
        */
        public static final int AlertDialog_multiChoiceItemLayout = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#singleChoiceItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:singleChoiceItemLayout
        */
        public static final int AlertDialog_singleChoiceItemLayout = 4;
        /** Attributes that can be used with a AppCompatTextView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #AppCompatTextView_android_textAppearance android:textAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #AppCompatTextView_textAllCaps com.revenuecat.purchases_sample:textAllCaps}</code></td><td></td></tr>
           </table>
           @see #AppCompatTextView_android_textAppearance
           @see #AppCompatTextView_textAllCaps
         */
        public static final int[] AppCompatTextView = {
            0x01010034, 0x7f010024
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textAppearance}
          attribute's value can be found in the {@link #AppCompatTextView} array.
          @attr name android:textAppearance
        */
        public static final int AppCompatTextView_android_textAppearance = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAllCaps}
          attribute's value can be found in the {@link #AppCompatTextView} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
          @attr name com.revenuecat.purchases_sample:textAllCaps
        */
        public static final int AppCompatTextView_textAllCaps = 1;
        /** Attributes that can be used with a CompoundButton.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #CompoundButton_android_button android:button}</code></td><td></td></tr>
           <tr><td><code>{@link #CompoundButton_buttonTint com.revenuecat.purchases_sample:buttonTint}</code></td><td></td></tr>
           <tr><td><code>{@link #CompoundButton_buttonTintMode com.revenuecat.purchases_sample:buttonTintMode}</code></td><td></td></tr>
           </table>
           @see #CompoundButton_android_button
           @see #CompoundButton_buttonTint
           @see #CompoundButton_buttonTintMode
         */
        public static final int[] CompoundButton = {
            0x01010107, 0x7f010025, 0x7f010026
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#button}
          attribute's value can be found in the {@link #CompoundButton} array.
          @attr name android:button
        */
        public static final int CompoundButton_android_button = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonTint}
          attribute's value can be found in the {@link #CompoundButton} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:buttonTint
        */
        public static final int CompoundButton_buttonTint = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonTintMode}
          attribute's value can be found in the {@link #CompoundButton} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:buttonTintMode
        */
        public static final int CompoundButton_buttonTintMode = 2;
        /** Attributes that can be used with a DrawerArrowToggle.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #DrawerArrowToggle_arrowHeadLength com.revenuecat.purchases_sample:arrowHeadLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_arrowShaftLength com.revenuecat.purchases_sample:arrowShaftLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_barLength com.revenuecat.purchases_sample:barLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_color com.revenuecat.purchases_sample:color}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_drawableSize com.revenuecat.purchases_sample:drawableSize}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_gapBetweenBars com.revenuecat.purchases_sample:gapBetweenBars}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_spinBars com.revenuecat.purchases_sample:spinBars}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_thickness com.revenuecat.purchases_sample:thickness}</code></td><td></td></tr>
           </table>
           @see #DrawerArrowToggle_arrowHeadLength
           @see #DrawerArrowToggle_arrowShaftLength
           @see #DrawerArrowToggle_barLength
           @see #DrawerArrowToggle_color
           @see #DrawerArrowToggle_drawableSize
           @see #DrawerArrowToggle_gapBetweenBars
           @see #DrawerArrowToggle_spinBars
           @see #DrawerArrowToggle_thickness
         */
        public static final int[] DrawerArrowToggle = {
            0x7f010027, 0x7f010028, 0x7f010029, 0x7f01002a,
            0x7f01002b, 0x7f01002c, 0x7f01002d, 0x7f01002e
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#arrowHeadLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:arrowHeadLength
        */
        public static final int DrawerArrowToggle_arrowHeadLength = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#arrowShaftLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:arrowShaftLength
        */
        public static final int DrawerArrowToggle_arrowShaftLength = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#barLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:barLength
        */
        public static final int DrawerArrowToggle_barLength = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#color}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:color
        */
        public static final int DrawerArrowToggle_color = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#drawableSize}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:drawableSize
        */
        public static final int DrawerArrowToggle_drawableSize = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#gapBetweenBars}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:gapBetweenBars
        */
        public static final int DrawerArrowToggle_gapBetweenBars = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#spinBars}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:spinBars
        */
        public static final int DrawerArrowToggle_spinBars = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#thickness}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:thickness
        */
        public static final int DrawerArrowToggle_thickness = 7;
        /** Attributes that can be used with a GenericDraweeHierarchy.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_actualImageScaleType com.revenuecat.purchases_sample:actualImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_backgroundImage com.revenuecat.purchases_sample:backgroundImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_fadeDuration com.revenuecat.purchases_sample:fadeDuration}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_failureImage com.revenuecat.purchases_sample:failureImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_failureImageScaleType com.revenuecat.purchases_sample:failureImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_overlayImage com.revenuecat.purchases_sample:overlayImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_placeholderImage com.revenuecat.purchases_sample:placeholderImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_placeholderImageScaleType com.revenuecat.purchases_sample:placeholderImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_pressedStateOverlayImage com.revenuecat.purchases_sample:pressedStateOverlayImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_progressBarAutoRotateInterval com.revenuecat.purchases_sample:progressBarAutoRotateInterval}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_progressBarImage com.revenuecat.purchases_sample:progressBarImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_progressBarImageScaleType com.revenuecat.purchases_sample:progressBarImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_retryImage com.revenuecat.purchases_sample:retryImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_retryImageScaleType com.revenuecat.purchases_sample:retryImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundAsCircle com.revenuecat.purchases_sample:roundAsCircle}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundBottomLeft com.revenuecat.purchases_sample:roundBottomLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundBottomRight com.revenuecat.purchases_sample:roundBottomRight}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundTopLeft com.revenuecat.purchases_sample:roundTopLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundTopRight com.revenuecat.purchases_sample:roundTopRight}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundWithOverlayColor com.revenuecat.purchases_sample:roundWithOverlayColor}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundedCornerRadius com.revenuecat.purchases_sample:roundedCornerRadius}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundingBorderColor com.revenuecat.purchases_sample:roundingBorderColor}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundingBorderPadding com.revenuecat.purchases_sample:roundingBorderPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_roundingBorderWidth com.revenuecat.purchases_sample:roundingBorderWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeHierarchy_viewAspectRatio com.revenuecat.purchases_sample:viewAspectRatio}</code></td><td></td></tr>
           </table>
           @see #GenericDraweeHierarchy_actualImageScaleType
           @see #GenericDraweeHierarchy_backgroundImage
           @see #GenericDraweeHierarchy_fadeDuration
           @see #GenericDraweeHierarchy_failureImage
           @see #GenericDraweeHierarchy_failureImageScaleType
           @see #GenericDraweeHierarchy_overlayImage
           @see #GenericDraweeHierarchy_placeholderImage
           @see #GenericDraweeHierarchy_placeholderImageScaleType
           @see #GenericDraweeHierarchy_pressedStateOverlayImage
           @see #GenericDraweeHierarchy_progressBarAutoRotateInterval
           @see #GenericDraweeHierarchy_progressBarImage
           @see #GenericDraweeHierarchy_progressBarImageScaleType
           @see #GenericDraweeHierarchy_retryImage
           @see #GenericDraweeHierarchy_retryImageScaleType
           @see #GenericDraweeHierarchy_roundAsCircle
           @see #GenericDraweeHierarchy_roundBottomLeft
           @see #GenericDraweeHierarchy_roundBottomRight
           @see #GenericDraweeHierarchy_roundTopLeft
           @see #GenericDraweeHierarchy_roundTopRight
           @see #GenericDraweeHierarchy_roundWithOverlayColor
           @see #GenericDraweeHierarchy_roundedCornerRadius
           @see #GenericDraweeHierarchy_roundingBorderColor
           @see #GenericDraweeHierarchy_roundingBorderPadding
           @see #GenericDraweeHierarchy_roundingBorderWidth
           @see #GenericDraweeHierarchy_viewAspectRatio
         */
        public static final int[] GenericDraweeHierarchy = {
            0x7f01002f, 0x7f010030, 0x7f010031, 0x7f010032,
            0x7f010033, 0x7f010034, 0x7f010035, 0x7f010036,
            0x7f010037, 0x7f010038, 0x7f010039, 0x7f01003a,
            0x7f01003b, 0x7f01003c, 0x7f01003d, 0x7f01003e,
            0x7f01003f, 0x7f010040, 0x7f010041, 0x7f010042,
            0x7f010043, 0x7f010044, 0x7f010045, 0x7f010046,
            0x7f010047
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actualImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:actualImageScaleType
        */
        public static final int GenericDraweeHierarchy_actualImageScaleType = 11;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:backgroundImage
        */
        public static final int GenericDraweeHierarchy_backgroundImage = 12;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#fadeDuration}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:fadeDuration
        */
        public static final int GenericDraweeHierarchy_fadeDuration = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#failureImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:failureImage
        */
        public static final int GenericDraweeHierarchy_failureImage = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#failureImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:failureImageScaleType
        */
        public static final int GenericDraweeHierarchy_failureImageScaleType = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#overlayImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:overlayImage
        */
        public static final int GenericDraweeHierarchy_overlayImage = 13;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#placeholderImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:placeholderImage
        */
        public static final int GenericDraweeHierarchy_placeholderImage = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#placeholderImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:placeholderImageScaleType
        */
        public static final int GenericDraweeHierarchy_placeholderImageScaleType = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#pressedStateOverlayImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:pressedStateOverlayImage
        */
        public static final int GenericDraweeHierarchy_pressedStateOverlayImage = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#progressBarAutoRotateInterval}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:progressBarAutoRotateInterval
        */
        public static final int GenericDraweeHierarchy_progressBarAutoRotateInterval = 10;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#progressBarImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:progressBarImage
        */
        public static final int GenericDraweeHierarchy_progressBarImage = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#progressBarImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:progressBarImageScaleType
        */
        public static final int GenericDraweeHierarchy_progressBarImageScaleType = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#retryImage}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:retryImage
        */
        public static final int GenericDraweeHierarchy_retryImage = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#retryImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:retryImageScaleType
        */
        public static final int GenericDraweeHierarchy_retryImageScaleType = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundAsCircle}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundAsCircle
        */
        public static final int GenericDraweeHierarchy_roundAsCircle = 15;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundBottomLeft}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundBottomLeft
        */
        public static final int GenericDraweeHierarchy_roundBottomLeft = 20;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundBottomRight}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundBottomRight
        */
        public static final int GenericDraweeHierarchy_roundBottomRight = 19;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundTopLeft}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundTopLeft
        */
        public static final int GenericDraweeHierarchy_roundTopLeft = 17;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundTopRight}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundTopRight
        */
        public static final int GenericDraweeHierarchy_roundTopRight = 18;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundWithOverlayColor}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundWithOverlayColor
        */
        public static final int GenericDraweeHierarchy_roundWithOverlayColor = 21;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundedCornerRadius}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundedCornerRadius
        */
        public static final int GenericDraweeHierarchy_roundedCornerRadius = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundingBorderColor}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundingBorderColor
        */
        public static final int GenericDraweeHierarchy_roundingBorderColor = 23;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundingBorderPadding}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundingBorderPadding
        */
        public static final int GenericDraweeHierarchy_roundingBorderPadding = 24;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#roundingBorderWidth}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:roundingBorderWidth
        */
        public static final int GenericDraweeHierarchy_roundingBorderWidth = 22;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#viewAspectRatio}
          attribute's value can be found in the {@link #GenericDraweeHierarchy} array.


          <p>Must be a floating point value, such as "<code>1.2</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:viewAspectRatio
        */
        public static final int GenericDraweeHierarchy_viewAspectRatio = 1;
        /** Attributes that can be used with a LinearLayoutCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_baselineAligned android:baselineAligned}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_baselineAlignedChildIndex android:baselineAlignedChildIndex}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_gravity android:gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_orientation android:orientation}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_weightSum android:weightSum}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_divider com.revenuecat.purchases_sample:divider}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_dividerPadding com.revenuecat.purchases_sample:dividerPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_measureWithLargestChild com.revenuecat.purchases_sample:measureWithLargestChild}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_showDividers com.revenuecat.purchases_sample:showDividers}</code></td><td></td></tr>
           </table>
           @see #LinearLayoutCompat_android_baselineAligned
           @see #LinearLayoutCompat_android_baselineAlignedChildIndex
           @see #LinearLayoutCompat_android_gravity
           @see #LinearLayoutCompat_android_orientation
           @see #LinearLayoutCompat_android_weightSum
           @see #LinearLayoutCompat_divider
           @see #LinearLayoutCompat_dividerPadding
           @see #LinearLayoutCompat_measureWithLargestChild
           @see #LinearLayoutCompat_showDividers
         */
        public static final int[] LinearLayoutCompat = {
            0x010100af, 0x010100c4, 0x01010126, 0x01010127,
            0x01010128, 0x7f01000b, 0x7f010048, 0x7f010049,
            0x7f01004a
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#baselineAligned}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:baselineAligned
        */
        public static final int LinearLayoutCompat_android_baselineAligned = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#baselineAlignedChildIndex}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:baselineAlignedChildIndex
        */
        public static final int LinearLayoutCompat_android_baselineAlignedChildIndex = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#gravity}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:gravity
        */
        public static final int LinearLayoutCompat_android_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orientation}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:orientation
        */
        public static final int LinearLayoutCompat_android_orientation = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#weightSum}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:weightSum
        */
        public static final int LinearLayoutCompat_android_weightSum = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#divider}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:divider
        */
        public static final int LinearLayoutCompat_divider = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dividerPadding}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:dividerPadding
        */
        public static final int LinearLayoutCompat_dividerPadding = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#measureWithLargestChild}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:measureWithLargestChild
        */
        public static final int LinearLayoutCompat_measureWithLargestChild = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#showDividers}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>beginning</code></td><td>1</td><td></td></tr>
<tr><td><code>middle</code></td><td>2</td><td></td></tr>
<tr><td><code>end</code></td><td>4</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:showDividers
        */
        public static final int LinearLayoutCompat_showDividers = 7;
        /** Attributes that can be used with a LinearLayoutCompat_Layout.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_gravity android:layout_gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_height android:layout_height}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_weight android:layout_weight}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_width android:layout_width}</code></td><td></td></tr>
           </table>
           @see #LinearLayoutCompat_Layout_android_layout_gravity
           @see #LinearLayoutCompat_Layout_android_layout_height
           @see #LinearLayoutCompat_Layout_android_layout_weight
           @see #LinearLayoutCompat_Layout_android_layout_width
         */
        public static final int[] LinearLayoutCompat_Layout = {
            0x010100b3, 0x010100f4, 0x010100f5, 0x01010181
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_gravity}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_gravity
        */
        public static final int LinearLayoutCompat_Layout_android_layout_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_height}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_height
        */
        public static final int LinearLayoutCompat_Layout_android_layout_height = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_weight}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_weight
        */
        public static final int LinearLayoutCompat_Layout_android_layout_weight = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_width}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_width
        */
        public static final int LinearLayoutCompat_Layout_android_layout_width = 1;
        /** Attributes that can be used with a ListPopupWindow.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ListPopupWindow_android_dropDownHorizontalOffset android:dropDownHorizontalOffset}</code></td><td></td></tr>
           <tr><td><code>{@link #ListPopupWindow_android_dropDownVerticalOffset android:dropDownVerticalOffset}</code></td><td></td></tr>
           </table>
           @see #ListPopupWindow_android_dropDownHorizontalOffset
           @see #ListPopupWindow_android_dropDownVerticalOffset
         */
        public static final int[] ListPopupWindow = {
            0x010102ac, 0x010102ad
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownHorizontalOffset}
          attribute's value can be found in the {@link #ListPopupWindow} array.
          @attr name android:dropDownHorizontalOffset
        */
        public static final int ListPopupWindow_android_dropDownHorizontalOffset = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownVerticalOffset}
          attribute's value can be found in the {@link #ListPopupWindow} array.
          @attr name android:dropDownVerticalOffset
        */
        public static final int ListPopupWindow_android_dropDownVerticalOffset = 1;
        /** Attributes that can be used with a MenuGroup.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuGroup_android_checkableBehavior android:checkableBehavior}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_enabled android:enabled}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_menuCategory android:menuCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_orderInCategory android:orderInCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_visible android:visible}</code></td><td></td></tr>
           </table>
           @see #MenuGroup_android_checkableBehavior
           @see #MenuGroup_android_enabled
           @see #MenuGroup_android_id
           @see #MenuGroup_android_menuCategory
           @see #MenuGroup_android_orderInCategory
           @see #MenuGroup_android_visible
         */
        public static final int[] MenuGroup = {
            0x0101000e, 0x010100d0, 0x01010194, 0x010101de,
            0x010101df, 0x010101e0
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checkableBehavior}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:checkableBehavior
        */
        public static final int MenuGroup_android_checkableBehavior = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#enabled}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:enabled
        */
        public static final int MenuGroup_android_enabled = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:id
        */
        public static final int MenuGroup_android_id = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#menuCategory}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:menuCategory
        */
        public static final int MenuGroup_android_menuCategory = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orderInCategory}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:orderInCategory
        */
        public static final int MenuGroup_android_orderInCategory = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#visible}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:visible
        */
        public static final int MenuGroup_android_visible = 2;
        /** Attributes that can be used with a MenuItem.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuItem_actionLayout com.revenuecat.purchases_sample:actionLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_actionProviderClass com.revenuecat.purchases_sample:actionProviderClass}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_actionViewClass com.revenuecat.purchases_sample:actionViewClass}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_alphabeticShortcut android:alphabeticShortcut}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_checkable android:checkable}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_checked android:checked}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_enabled android:enabled}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_icon android:icon}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_menuCategory android:menuCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_numericShortcut android:numericShortcut}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_onClick android:onClick}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_orderInCategory android:orderInCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_title android:title}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_titleCondensed android:titleCondensed}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_visible android:visible}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_showAsAction com.revenuecat.purchases_sample:showAsAction}</code></td><td></td></tr>
           </table>
           @see #MenuItem_actionLayout
           @see #MenuItem_actionProviderClass
           @see #MenuItem_actionViewClass
           @see #MenuItem_android_alphabeticShortcut
           @see #MenuItem_android_checkable
           @see #MenuItem_android_checked
           @see #MenuItem_android_enabled
           @see #MenuItem_android_icon
           @see #MenuItem_android_id
           @see #MenuItem_android_menuCategory
           @see #MenuItem_android_numericShortcut
           @see #MenuItem_android_onClick
           @see #MenuItem_android_orderInCategory
           @see #MenuItem_android_title
           @see #MenuItem_android_titleCondensed
           @see #MenuItem_android_visible
           @see #MenuItem_showAsAction
         */
        public static final int[] MenuItem = {
            0x01010002, 0x0101000e, 0x010100d0, 0x01010106,
            0x01010194, 0x010101de, 0x010101df, 0x010101e1,
            0x010101e2, 0x010101e3, 0x010101e4, 0x010101e5,
            0x0101026f, 0x7f01004b, 0x7f01004c, 0x7f01004d,
            0x7f01004e
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionLayout}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionLayout
        */
        public static final int MenuItem_actionLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionProviderClass}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:actionProviderClass
        */
        public static final int MenuItem_actionProviderClass = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionViewClass}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:actionViewClass
        */
        public static final int MenuItem_actionViewClass = 15;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#alphabeticShortcut}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:alphabeticShortcut
        */
        public static final int MenuItem_android_alphabeticShortcut = 9;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checkable}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:checkable
        */
        public static final int MenuItem_android_checkable = 11;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checked}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:checked
        */
        public static final int MenuItem_android_checked = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#enabled}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:enabled
        */
        public static final int MenuItem_android_enabled = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#icon}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:icon
        */
        public static final int MenuItem_android_icon = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:id
        */
        public static final int MenuItem_android_id = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#menuCategory}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:menuCategory
        */
        public static final int MenuItem_android_menuCategory = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#numericShortcut}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:numericShortcut
        */
        public static final int MenuItem_android_numericShortcut = 10;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#onClick}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:onClick
        */
        public static final int MenuItem_android_onClick = 12;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orderInCategory}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:orderInCategory
        */
        public static final int MenuItem_android_orderInCategory = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#title}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:title
        */
        public static final int MenuItem_android_title = 7;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#titleCondensed}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:titleCondensed
        */
        public static final int MenuItem_android_titleCondensed = 8;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#visible}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:visible
        */
        public static final int MenuItem_android_visible = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#showAsAction}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>never</code></td><td>0</td><td></td></tr>
<tr><td><code>ifRoom</code></td><td>1</td><td></td></tr>
<tr><td><code>always</code></td><td>2</td><td></td></tr>
<tr><td><code>withText</code></td><td>4</td><td></td></tr>
<tr><td><code>collapseActionView</code></td><td>8</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:showAsAction
        */
        public static final int MenuItem_showAsAction = 13;
        /** Attributes that can be used with a MenuView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuView_android_headerBackground android:headerBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_horizontalDivider android:horizontalDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemBackground android:itemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemIconDisabledAlpha android:itemIconDisabledAlpha}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemTextAppearance android:itemTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_verticalDivider android:verticalDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_windowAnimationStyle android:windowAnimationStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_preserveIconSpacing com.revenuecat.purchases_sample:preserveIconSpacing}</code></td><td></td></tr>
           </table>
           @see #MenuView_android_headerBackground
           @see #MenuView_android_horizontalDivider
           @see #MenuView_android_itemBackground
           @see #MenuView_android_itemIconDisabledAlpha
           @see #MenuView_android_itemTextAppearance
           @see #MenuView_android_verticalDivider
           @see #MenuView_android_windowAnimationStyle
           @see #MenuView_preserveIconSpacing
         */
        public static final int[] MenuView = {
            0x010100ae, 0x0101012c, 0x0101012d, 0x0101012e,
            0x0101012f, 0x01010130, 0x01010131, 0x7f01004f
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#headerBackground}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:headerBackground
        */
        public static final int MenuView_android_headerBackground = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#horizontalDivider}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:horizontalDivider
        */
        public static final int MenuView_android_horizontalDivider = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemBackground}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemBackground
        */
        public static final int MenuView_android_itemBackground = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemIconDisabledAlpha}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemIconDisabledAlpha
        */
        public static final int MenuView_android_itemIconDisabledAlpha = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemTextAppearance}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemTextAppearance
        */
        public static final int MenuView_android_itemTextAppearance = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#verticalDivider}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:verticalDivider
        */
        public static final int MenuView_android_verticalDivider = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowAnimationStyle}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:windowAnimationStyle
        */
        public static final int MenuView_android_windowAnimationStyle = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#preserveIconSpacing}
          attribute's value can be found in the {@link #MenuView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:preserveIconSpacing
        */
        public static final int MenuView_preserveIconSpacing = 7;
        /** Attributes that can be used with a PopupWindow.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #PopupWindow_android_popupBackground android:popupBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #PopupWindow_overlapAnchor com.revenuecat.purchases_sample:overlapAnchor}</code></td><td></td></tr>
           </table>
           @see #PopupWindow_android_popupBackground
           @see #PopupWindow_overlapAnchor
         */
        public static final int[] PopupWindow = {
            0x01010176, 0x7f010050
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#popupBackground}
          attribute's value can be found in the {@link #PopupWindow} array.
          @attr name android:popupBackground
        */
        public static final int PopupWindow_android_popupBackground = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#overlapAnchor}
          attribute's value can be found in the {@link #PopupWindow} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:overlapAnchor
        */
        public static final int PopupWindow_overlapAnchor = 1;
        /** Attributes that can be used with a PopupWindowBackgroundState.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #PopupWindowBackgroundState_state_above_anchor com.revenuecat.purchases_sample:state_above_anchor}</code></td><td></td></tr>
           </table>
           @see #PopupWindowBackgroundState_state_above_anchor
         */
        public static final int[] PopupWindowBackgroundState = {
            0x7f010051
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#state_above_anchor}
          attribute's value can be found in the {@link #PopupWindowBackgroundState} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:state_above_anchor
        */
        public static final int PopupWindowBackgroundState_state_above_anchor = 0;
        /** Attributes that can be used with a SearchView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #SearchView_android_focusable android:focusable}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_imeOptions android:imeOptions}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_inputType android:inputType}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_maxWidth android:maxWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_closeIcon com.revenuecat.purchases_sample:closeIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_commitIcon com.revenuecat.purchases_sample:commitIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_defaultQueryHint com.revenuecat.purchases_sample:defaultQueryHint}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_goIcon com.revenuecat.purchases_sample:goIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_iconifiedByDefault com.revenuecat.purchases_sample:iconifiedByDefault}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_layout com.revenuecat.purchases_sample:layout}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_queryBackground com.revenuecat.purchases_sample:queryBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_queryHint com.revenuecat.purchases_sample:queryHint}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_searchHintIcon com.revenuecat.purchases_sample:searchHintIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_searchIcon com.revenuecat.purchases_sample:searchIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_submitBackground com.revenuecat.purchases_sample:submitBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_suggestionRowLayout com.revenuecat.purchases_sample:suggestionRowLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_voiceIcon com.revenuecat.purchases_sample:voiceIcon}</code></td><td></td></tr>
           </table>
           @see #SearchView_android_focusable
           @see #SearchView_android_imeOptions
           @see #SearchView_android_inputType
           @see #SearchView_android_maxWidth
           @see #SearchView_closeIcon
           @see #SearchView_commitIcon
           @see #SearchView_defaultQueryHint
           @see #SearchView_goIcon
           @see #SearchView_iconifiedByDefault
           @see #SearchView_layout
           @see #SearchView_queryBackground
           @see #SearchView_queryHint
           @see #SearchView_searchHintIcon
           @see #SearchView_searchIcon
           @see #SearchView_submitBackground
           @see #SearchView_suggestionRowLayout
           @see #SearchView_voiceIcon
         */
        public static final int[] SearchView = {
            0x010100da, 0x0101011f, 0x01010220, 0x01010264,
            0x7f010052, 0x7f010053, 0x7f010054, 0x7f010055,
            0x7f010056, 0x7f010057, 0x7f010058, 0x7f010059,
            0x7f01005a, 0x7f01005b, 0x7f01005c, 0x7f01005d,
            0x7f01005e
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#focusable}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:focusable
        */
        public static final int SearchView_android_focusable = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#imeOptions}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:imeOptions
        */
        public static final int SearchView_android_imeOptions = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#inputType}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:inputType
        */
        public static final int SearchView_android_inputType = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#maxWidth}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:maxWidth
        */
        public static final int SearchView_android_maxWidth = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#closeIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:closeIcon
        */
        public static final int SearchView_closeIcon = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#commitIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:commitIcon
        */
        public static final int SearchView_commitIcon = 13;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#defaultQueryHint}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:defaultQueryHint
        */
        public static final int SearchView_defaultQueryHint = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#goIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:goIcon
        */
        public static final int SearchView_goIcon = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#iconifiedByDefault}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:iconifiedByDefault
        */
        public static final int SearchView_iconifiedByDefault = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#layout}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:layout
        */
        public static final int SearchView_layout = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#queryBackground}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:queryBackground
        */
        public static final int SearchView_queryBackground = 15;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#queryHint}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:queryHint
        */
        public static final int SearchView_queryHint = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#searchHintIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:searchHintIcon
        */
        public static final int SearchView_searchHintIcon = 11;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#searchIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:searchIcon
        */
        public static final int SearchView_searchIcon = 10;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#submitBackground}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:submitBackground
        */
        public static final int SearchView_submitBackground = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#suggestionRowLayout}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:suggestionRowLayout
        */
        public static final int SearchView_suggestionRowLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#voiceIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:voiceIcon
        */
        public static final int SearchView_voiceIcon = 12;
        /** Attributes that can be used with a SimpleDraweeView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #SimpleDraweeView_actualImageResource com.revenuecat.purchases_sample:actualImageResource}</code></td><td></td></tr>
           <tr><td><code>{@link #SimpleDraweeView_actualImageUri com.revenuecat.purchases_sample:actualImageUri}</code></td><td></td></tr>
           </table>
           @see #SimpleDraweeView_actualImageResource
           @see #SimpleDraweeView_actualImageUri
         */
        public static final int[] SimpleDraweeView = {
            0x7f01005f, 0x7f010060
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actualImageResource}
          attribute's value can be found in the {@link #SimpleDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actualImageResource
        */
        public static final int SimpleDraweeView_actualImageResource = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actualImageUri}
          attribute's value can be found in the {@link #SimpleDraweeView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:actualImageUri
        */
        public static final int SimpleDraweeView_actualImageUri = 0;
        /** Attributes that can be used with a Spinner.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Spinner_android_dropDownWidth android:dropDownWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_android_popupBackground android:popupBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_android_prompt android:prompt}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_popupTheme com.revenuecat.purchases_sample:popupTheme}</code></td><td></td></tr>
           </table>
           @see #Spinner_android_dropDownWidth
           @see #Spinner_android_popupBackground
           @see #Spinner_android_prompt
           @see #Spinner_popupTheme
         */
        public static final int[] Spinner = {
            0x01010176, 0x0101017b, 0x01010262, 0x7f01001b
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownWidth}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:dropDownWidth
        */
        public static final int Spinner_android_dropDownWidth = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#popupBackground}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:popupBackground
        */
        public static final int Spinner_android_popupBackground = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#prompt}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:prompt
        */
        public static final int Spinner_android_prompt = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#popupTheme}
          attribute's value can be found in the {@link #Spinner} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:popupTheme
        */
        public static final int Spinner_popupTheme = 3;
        /** Attributes that can be used with a SwitchCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #SwitchCompat_android_textOff android:textOff}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_android_textOn android:textOn}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_android_thumb android:thumb}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_showText com.revenuecat.purchases_sample:showText}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_splitTrack com.revenuecat.purchases_sample:splitTrack}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchMinWidth com.revenuecat.purchases_sample:switchMinWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchPadding com.revenuecat.purchases_sample:switchPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchTextAppearance com.revenuecat.purchases_sample:switchTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_thumbTextPadding com.revenuecat.purchases_sample:thumbTextPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_track com.revenuecat.purchases_sample:track}</code></td><td></td></tr>
           </table>
           @see #SwitchCompat_android_textOff
           @see #SwitchCompat_android_textOn
           @see #SwitchCompat_android_thumb
           @see #SwitchCompat_showText
           @see #SwitchCompat_splitTrack
           @see #SwitchCompat_switchMinWidth
           @see #SwitchCompat_switchPadding
           @see #SwitchCompat_switchTextAppearance
           @see #SwitchCompat_thumbTextPadding
           @see #SwitchCompat_track
         */
        public static final int[] SwitchCompat = {
            0x01010124, 0x01010125, 0x01010142, 0x7f010061,
            0x7f010062, 0x7f010063, 0x7f010064, 0x7f010065,
            0x7f010066, 0x7f010067
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textOff}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:textOff
        */
        public static final int SwitchCompat_android_textOff = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textOn}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:textOn
        */
        public static final int SwitchCompat_android_textOn = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#thumb}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:thumb
        */
        public static final int SwitchCompat_android_thumb = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#showText}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:showText
        */
        public static final int SwitchCompat_showText = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#splitTrack}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:splitTrack
        */
        public static final int SwitchCompat_splitTrack = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#switchMinWidth}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:switchMinWidth
        */
        public static final int SwitchCompat_switchMinWidth = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#switchPadding}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:switchPadding
        */
        public static final int SwitchCompat_switchPadding = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#switchTextAppearance}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:switchTextAppearance
        */
        public static final int SwitchCompat_switchTextAppearance = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#thumbTextPadding}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:thumbTextPadding
        */
        public static final int SwitchCompat_thumbTextPadding = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#track}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:track
        */
        public static final int SwitchCompat_track = 3;
        /** Attributes that can be used with a TextAppearance.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #TextAppearance_android_shadowColor android:shadowColor}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_shadowDx android:shadowDx}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_shadowDy android:shadowDy}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_shadowRadius android:shadowRadius}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_textColor android:textColor}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_textSize android:textSize}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_textStyle android:textStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_typeface android:typeface}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_textAllCaps com.revenuecat.purchases_sample:textAllCaps}</code></td><td></td></tr>
           </table>
           @see #TextAppearance_android_shadowColor
           @see #TextAppearance_android_shadowDx
           @see #TextAppearance_android_shadowDy
           @see #TextAppearance_android_shadowRadius
           @see #TextAppearance_android_textColor
           @see #TextAppearance_android_textSize
           @see #TextAppearance_android_textStyle
           @see #TextAppearance_android_typeface
           @see #TextAppearance_textAllCaps
         */
        public static final int[] TextAppearance = {
            0x01010095, 0x01010096, 0x01010097, 0x01010098,
            0x01010161, 0x01010162, 0x01010163, 0x01010164,
            0x7f010024
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowColor}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:shadowColor
        */
        public static final int TextAppearance_android_shadowColor = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowDx}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:shadowDx
        */
        public static final int TextAppearance_android_shadowDx = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowDy}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:shadowDy
        */
        public static final int TextAppearance_android_shadowDy = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowRadius}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:shadowRadius
        */
        public static final int TextAppearance_android_shadowRadius = 7;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textColor}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textColor
        */
        public static final int TextAppearance_android_textColor = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textSize}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textSize
        */
        public static final int TextAppearance_android_textSize = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textStyle}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textStyle
        */
        public static final int TextAppearance_android_textStyle = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#typeface}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:typeface
        */
        public static final int TextAppearance_android_typeface = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAllCaps}
          attribute's value can be found in the {@link #TextAppearance} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
          @attr name com.revenuecat.purchases_sample:textAllCaps
        */
        public static final int TextAppearance_textAllCaps = 8;
        /** Attributes that can be used with a TextStyle.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #TextStyle_android_ellipsize android:ellipsize}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_maxLines android:maxLines}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_shadowColor android:shadowColor}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_shadowDx android:shadowDx}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_shadowDy android:shadowDy}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_shadowRadius android:shadowRadius}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_singleLine android:singleLine}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_textAppearance android:textAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_textColor android:textColor}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_textSize android:textSize}</code></td><td></td></tr>
           <tr><td><code>{@link #TextStyle_android_textStyle android:textStyle}</code></td><td></td></tr>
           </table>
           @see #TextStyle_android_ellipsize
           @see #TextStyle_android_maxLines
           @see #TextStyle_android_shadowColor
           @see #TextStyle_android_shadowDx
           @see #TextStyle_android_shadowDy
           @see #TextStyle_android_shadowRadius
           @see #TextStyle_android_singleLine
           @see #TextStyle_android_textAppearance
           @see #TextStyle_android_textColor
           @see #TextStyle_android_textSize
           @see #TextStyle_android_textStyle
         */
        public static final int[] TextStyle = {
            0x01010034, 0x01010095, 0x01010097, 0x01010098,
            0x010100ab, 0x01010153, 0x0101015d, 0x01010161,
            0x01010162, 0x01010163, 0x01010164
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#ellipsize}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:ellipsize
        */
        public static final int TextStyle_android_ellipsize = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#maxLines}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:maxLines
        */
        public static final int TextStyle_android_maxLines = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowColor}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:shadowColor
        */
        public static final int TextStyle_android_shadowColor = 7;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowDx}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:shadowDx
        */
        public static final int TextStyle_android_shadowDx = 8;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowDy}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:shadowDy
        */
        public static final int TextStyle_android_shadowDy = 9;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#shadowRadius}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:shadowRadius
        */
        public static final int TextStyle_android_shadowRadius = 10;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#singleLine}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:singleLine
        */
        public static final int TextStyle_android_singleLine = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textAppearance}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:textAppearance
        */
        public static final int TextStyle_android_textAppearance = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textColor}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:textColor
        */
        public static final int TextStyle_android_textColor = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textSize}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:textSize
        */
        public static final int TextStyle_android_textSize = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textStyle}
          attribute's value can be found in the {@link #TextStyle} array.
          @attr name android:textStyle
        */
        public static final int TextStyle_android_textStyle = 2;
        /** Attributes that can be used with a Theme.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Theme_actionBarDivider com.revenuecat.purchases_sample:actionBarDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarItemBackground com.revenuecat.purchases_sample:actionBarItemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarPopupTheme com.revenuecat.purchases_sample:actionBarPopupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarSize com.revenuecat.purchases_sample:actionBarSize}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarSplitStyle com.revenuecat.purchases_sample:actionBarSplitStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarStyle com.revenuecat.purchases_sample:actionBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabBarStyle com.revenuecat.purchases_sample:actionBarTabBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabStyle com.revenuecat.purchases_sample:actionBarTabStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabTextStyle com.revenuecat.purchases_sample:actionBarTabTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTheme com.revenuecat.purchases_sample:actionBarTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarWidgetTheme com.revenuecat.purchases_sample:actionBarWidgetTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionButtonStyle com.revenuecat.purchases_sample:actionButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionDropDownStyle com.revenuecat.purchases_sample:actionDropDownStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionMenuTextAppearance com.revenuecat.purchases_sample:actionMenuTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionMenuTextColor com.revenuecat.purchases_sample:actionMenuTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeBackground com.revenuecat.purchases_sample:actionModeBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCloseButtonStyle com.revenuecat.purchases_sample:actionModeCloseButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCloseDrawable com.revenuecat.purchases_sample:actionModeCloseDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCopyDrawable com.revenuecat.purchases_sample:actionModeCopyDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCutDrawable com.revenuecat.purchases_sample:actionModeCutDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeFindDrawable com.revenuecat.purchases_sample:actionModeFindDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModePasteDrawable com.revenuecat.purchases_sample:actionModePasteDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModePopupWindowStyle com.revenuecat.purchases_sample:actionModePopupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeSelectAllDrawable com.revenuecat.purchases_sample:actionModeSelectAllDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeShareDrawable com.revenuecat.purchases_sample:actionModeShareDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeSplitBackground com.revenuecat.purchases_sample:actionModeSplitBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeStyle com.revenuecat.purchases_sample:actionModeStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeWebSearchDrawable com.revenuecat.purchases_sample:actionModeWebSearchDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionOverflowButtonStyle com.revenuecat.purchases_sample:actionOverflowButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionOverflowMenuStyle com.revenuecat.purchases_sample:actionOverflowMenuStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_activityChooserViewStyle com.revenuecat.purchases_sample:activityChooserViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogButtonGroupStyle com.revenuecat.purchases_sample:alertDialogButtonGroupStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogCenterButtons com.revenuecat.purchases_sample:alertDialogCenterButtons}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogStyle com.revenuecat.purchases_sample:alertDialogStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogTheme com.revenuecat.purchases_sample:alertDialogTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_android_windowAnimationStyle android:windowAnimationStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_android_windowIsFloating android:windowIsFloating}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_autoCompleteTextViewStyle com.revenuecat.purchases_sample:autoCompleteTextViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_borderlessButtonStyle com.revenuecat.purchases_sample:borderlessButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarButtonStyle com.revenuecat.purchases_sample:buttonBarButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarNegativeButtonStyle com.revenuecat.purchases_sample:buttonBarNegativeButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarNeutralButtonStyle com.revenuecat.purchases_sample:buttonBarNeutralButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarPositiveButtonStyle com.revenuecat.purchases_sample:buttonBarPositiveButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarStyle com.revenuecat.purchases_sample:buttonBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonStyle com.revenuecat.purchases_sample:buttonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonStyleSmall com.revenuecat.purchases_sample:buttonStyleSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_checkboxStyle com.revenuecat.purchases_sample:checkboxStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_checkedTextViewStyle com.revenuecat.purchases_sample:checkedTextViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorAccent com.revenuecat.purchases_sample:colorAccent}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorButtonNormal com.revenuecat.purchases_sample:colorButtonNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlActivated com.revenuecat.purchases_sample:colorControlActivated}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlHighlight com.revenuecat.purchases_sample:colorControlHighlight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlNormal com.revenuecat.purchases_sample:colorControlNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorPrimary com.revenuecat.purchases_sample:colorPrimary}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorPrimaryDark com.revenuecat.purchases_sample:colorPrimaryDark}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorSwitchThumbNormal com.revenuecat.purchases_sample:colorSwitchThumbNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_controlBackground com.revenuecat.purchases_sample:controlBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dialogPreferredPadding com.revenuecat.purchases_sample:dialogPreferredPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dialogTheme com.revenuecat.purchases_sample:dialogTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dividerHorizontal com.revenuecat.purchases_sample:dividerHorizontal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dividerVertical com.revenuecat.purchases_sample:dividerVertical}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dropDownListViewStyle com.revenuecat.purchases_sample:dropDownListViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dropdownListPreferredItemHeight com.revenuecat.purchases_sample:dropdownListPreferredItemHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextBackground com.revenuecat.purchases_sample:editTextBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextColor com.revenuecat.purchases_sample:editTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextStyle com.revenuecat.purchases_sample:editTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_homeAsUpIndicator com.revenuecat.purchases_sample:homeAsUpIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listChoiceBackgroundIndicator com.revenuecat.purchases_sample:listChoiceBackgroundIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listDividerAlertDialog com.revenuecat.purchases_sample:listDividerAlertDialog}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPopupWindowStyle com.revenuecat.purchases_sample:listPopupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeight com.revenuecat.purchases_sample:listPreferredItemHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeightLarge com.revenuecat.purchases_sample:listPreferredItemHeightLarge}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeightSmall com.revenuecat.purchases_sample:listPreferredItemHeightSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemPaddingLeft com.revenuecat.purchases_sample:listPreferredItemPaddingLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemPaddingRight com.revenuecat.purchases_sample:listPreferredItemPaddingRight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelBackground com.revenuecat.purchases_sample:panelBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelMenuListTheme com.revenuecat.purchases_sample:panelMenuListTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelMenuListWidth com.revenuecat.purchases_sample:panelMenuListWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_popupMenuStyle com.revenuecat.purchases_sample:popupMenuStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_popupWindowStyle com.revenuecat.purchases_sample:popupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_radioButtonStyle com.revenuecat.purchases_sample:radioButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_ratingBarStyle com.revenuecat.purchases_sample:ratingBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_searchViewStyle com.revenuecat.purchases_sample:searchViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_selectableItemBackground com.revenuecat.purchases_sample:selectableItemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_selectableItemBackgroundBorderless com.revenuecat.purchases_sample:selectableItemBackgroundBorderless}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_spinnerDropDownItemStyle com.revenuecat.purchases_sample:spinnerDropDownItemStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_spinnerStyle com.revenuecat.purchases_sample:spinnerStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_switchStyle com.revenuecat.purchases_sample:switchStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceLargePopupMenu com.revenuecat.purchases_sample:textAppearanceLargePopupMenu}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceListItem com.revenuecat.purchases_sample:textAppearanceListItem}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceListItemSmall com.revenuecat.purchases_sample:textAppearanceListItemSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSearchResultSubtitle com.revenuecat.purchases_sample:textAppearanceSearchResultSubtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSearchResultTitle com.revenuecat.purchases_sample:textAppearanceSearchResultTitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSmallPopupMenu com.revenuecat.purchases_sample:textAppearanceSmallPopupMenu}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textColorAlertDialogListItem com.revenuecat.purchases_sample:textColorAlertDialogListItem}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textColorSearchUrl com.revenuecat.purchases_sample:textColorSearchUrl}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_toolbarNavigationButtonStyle com.revenuecat.purchases_sample:toolbarNavigationButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_toolbarStyle com.revenuecat.purchases_sample:toolbarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionBar com.revenuecat.purchases_sample:windowActionBar}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionBarOverlay com.revenuecat.purchases_sample:windowActionBarOverlay}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionModeOverlay com.revenuecat.purchases_sample:windowActionModeOverlay}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedHeightMajor com.revenuecat.purchases_sample:windowFixedHeightMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedHeightMinor com.revenuecat.purchases_sample:windowFixedHeightMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedWidthMajor com.revenuecat.purchases_sample:windowFixedWidthMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedWidthMinor com.revenuecat.purchases_sample:windowFixedWidthMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowMinWidthMajor com.revenuecat.purchases_sample:windowMinWidthMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowMinWidthMinor com.revenuecat.purchases_sample:windowMinWidthMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowNoTitle com.revenuecat.purchases_sample:windowNoTitle}</code></td><td></td></tr>
           </table>
           @see #Theme_actionBarDivider
           @see #Theme_actionBarItemBackground
           @see #Theme_actionBarPopupTheme
           @see #Theme_actionBarSize
           @see #Theme_actionBarSplitStyle
           @see #Theme_actionBarStyle
           @see #Theme_actionBarTabBarStyle
           @see #Theme_actionBarTabStyle
           @see #Theme_actionBarTabTextStyle
           @see #Theme_actionBarTheme
           @see #Theme_actionBarWidgetTheme
           @see #Theme_actionButtonStyle
           @see #Theme_actionDropDownStyle
           @see #Theme_actionMenuTextAppearance
           @see #Theme_actionMenuTextColor
           @see #Theme_actionModeBackground
           @see #Theme_actionModeCloseButtonStyle
           @see #Theme_actionModeCloseDrawable
           @see #Theme_actionModeCopyDrawable
           @see #Theme_actionModeCutDrawable
           @see #Theme_actionModeFindDrawable
           @see #Theme_actionModePasteDrawable
           @see #Theme_actionModePopupWindowStyle
           @see #Theme_actionModeSelectAllDrawable
           @see #Theme_actionModeShareDrawable
           @see #Theme_actionModeSplitBackground
           @see #Theme_actionModeStyle
           @see #Theme_actionModeWebSearchDrawable
           @see #Theme_actionOverflowButtonStyle
           @see #Theme_actionOverflowMenuStyle
           @see #Theme_activityChooserViewStyle
           @see #Theme_alertDialogButtonGroupStyle
           @see #Theme_alertDialogCenterButtons
           @see #Theme_alertDialogStyle
           @see #Theme_alertDialogTheme
           @see #Theme_android_windowAnimationStyle
           @see #Theme_android_windowIsFloating
           @see #Theme_autoCompleteTextViewStyle
           @see #Theme_borderlessButtonStyle
           @see #Theme_buttonBarButtonStyle
           @see #Theme_buttonBarNegativeButtonStyle
           @see #Theme_buttonBarNeutralButtonStyle
           @see #Theme_buttonBarPositiveButtonStyle
           @see #Theme_buttonBarStyle
           @see #Theme_buttonStyle
           @see #Theme_buttonStyleSmall
           @see #Theme_checkboxStyle
           @see #Theme_checkedTextViewStyle
           @see #Theme_colorAccent
           @see #Theme_colorButtonNormal
           @see #Theme_colorControlActivated
           @see #Theme_colorControlHighlight
           @see #Theme_colorControlNormal
           @see #Theme_colorPrimary
           @see #Theme_colorPrimaryDark
           @see #Theme_colorSwitchThumbNormal
           @see #Theme_controlBackground
           @see #Theme_dialogPreferredPadding
           @see #Theme_dialogTheme
           @see #Theme_dividerHorizontal
           @see #Theme_dividerVertical
           @see #Theme_dropDownListViewStyle
           @see #Theme_dropdownListPreferredItemHeight
           @see #Theme_editTextBackground
           @see #Theme_editTextColor
           @see #Theme_editTextStyle
           @see #Theme_homeAsUpIndicator
           @see #Theme_listChoiceBackgroundIndicator
           @see #Theme_listDividerAlertDialog
           @see #Theme_listPopupWindowStyle
           @see #Theme_listPreferredItemHeight
           @see #Theme_listPreferredItemHeightLarge
           @see #Theme_listPreferredItemHeightSmall
           @see #Theme_listPreferredItemPaddingLeft
           @see #Theme_listPreferredItemPaddingRight
           @see #Theme_panelBackground
           @see #Theme_panelMenuListTheme
           @see #Theme_panelMenuListWidth
           @see #Theme_popupMenuStyle
           @see #Theme_popupWindowStyle
           @see #Theme_radioButtonStyle
           @see #Theme_ratingBarStyle
           @see #Theme_searchViewStyle
           @see #Theme_selectableItemBackground
           @see #Theme_selectableItemBackgroundBorderless
           @see #Theme_spinnerDropDownItemStyle
           @see #Theme_spinnerStyle
           @see #Theme_switchStyle
           @see #Theme_textAppearanceLargePopupMenu
           @see #Theme_textAppearanceListItem
           @see #Theme_textAppearanceListItemSmall
           @see #Theme_textAppearanceSearchResultSubtitle
           @see #Theme_textAppearanceSearchResultTitle
           @see #Theme_textAppearanceSmallPopupMenu
           @see #Theme_textColorAlertDialogListItem
           @see #Theme_textColorSearchUrl
           @see #Theme_toolbarNavigationButtonStyle
           @see #Theme_toolbarStyle
           @see #Theme_windowActionBar
           @see #Theme_windowActionBarOverlay
           @see #Theme_windowActionModeOverlay
           @see #Theme_windowFixedHeightMajor
           @see #Theme_windowFixedHeightMinor
           @see #Theme_windowFixedWidthMajor
           @see #Theme_windowFixedWidthMinor
           @see #Theme_windowMinWidthMajor
           @see #Theme_windowMinWidthMinor
           @see #Theme_windowNoTitle
         */
        public static final int[] Theme = {
            0x01010057, 0x010100ae, 0x7f010068, 0x7f010069,
            0x7f01006a, 0x7f01006b, 0x7f01006c, 0x7f01006d,
            0x7f01006e, 0x7f01006f, 0x7f010070, 0x7f010071,
            0x7f010072, 0x7f010073, 0x7f010074, 0x7f010075,
            0x7f010076, 0x7f010077, 0x7f010078, 0x7f010079,
            0x7f01007a, 0x7f01007b, 0x7f01007c, 0x7f01007d,
            0x7f01007e, 0x7f01007f, 0x7f010080, 0x7f010081,
            0x7f010082, 0x7f010083, 0x7f010084, 0x7f010085,
            0x7f010086, 0x7f010087, 0x7f010088, 0x7f010089,
            0x7f01008a, 0x7f01008b, 0x7f01008c, 0x7f01008d,
            0x7f01008e, 0x7f01008f, 0x7f010090, 0x7f010091,
            0x7f010092, 0x7f010093, 0x7f010094, 0x7f010095,
            0x7f010096, 0x7f010097, 0x7f010098, 0x7f010099,
            0x7f01009a, 0x7f01009b, 0x7f01009c, 0x7f01009d,
            0x7f01009e, 0x7f01009f, 0x7f0100a0, 0x7f0100a1,
            0x7f0100a2, 0x7f0100a3, 0x7f0100a4, 0x7f0100a5,
            0x7f0100a6, 0x7f0100a7, 0x7f0100a8, 0x7f0100a9,
            0x7f0100aa, 0x7f0100ab, 0x7f0100ac, 0x7f0100ad,
            0x7f0100ae, 0x7f0100af, 0x7f0100b0, 0x7f0100b1,
            0x7f0100b2, 0x7f0100b3, 0x7f0100b4, 0x7f0100b5,
            0x7f0100b6, 0x7f0100b7, 0x7f0100b8, 0x7f0100b9,
            0x7f0100ba, 0x7f0100bb, 0x7f0100bc, 0x7f0100bd,
            0x7f0100be, 0x7f0100bf, 0x7f0100c0, 0x7f0100c1,
            0x7f0100c2, 0x7f0100c3, 0x7f0100c4, 0x7f0100c5,
            0x7f0100c6, 0x7f0100c7, 0x7f0100c8, 0x7f0100c9,
            0x7f0100ca, 0x7f0100cb, 0x7f0100cc, 0x7f0100cd,
            0x7f0100ce, 0x7f0100cf, 0x7f0100d0, 0x7f0100d1
        };
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarDivider}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarDivider
        */
        public static final int Theme_actionBarDivider = 23;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarItemBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarItemBackground
        */
        public static final int Theme_actionBarItemBackground = 24;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarPopupTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarPopupTheme
        */
        public static final int Theme_actionBarPopupTheme = 17;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarSize}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
<p>May be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>wrap_content</code></td><td>0</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:actionBarSize
        */
        public static final int Theme_actionBarSize = 22;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarSplitStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarSplitStyle
        */
        public static final int Theme_actionBarSplitStyle = 19;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarStyle
        */
        public static final int Theme_actionBarStyle = 18;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarTabBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarTabBarStyle
        */
        public static final int Theme_actionBarTabBarStyle = 13;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarTabStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarTabStyle
        */
        public static final int Theme_actionBarTabStyle = 12;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarTabTextStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarTabTextStyle
        */
        public static final int Theme_actionBarTabTextStyle = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarTheme
        */
        public static final int Theme_actionBarTheme = 20;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionBarWidgetTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionBarWidgetTheme
        */
        public static final int Theme_actionBarWidgetTheme = 21;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionButtonStyle
        */
        public static final int Theme_actionButtonStyle = 49;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionDropDownStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionDropDownStyle
        */
        public static final int Theme_actionDropDownStyle = 45;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionMenuTextAppearance}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionMenuTextAppearance
        */
        public static final int Theme_actionMenuTextAppearance = 25;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionMenuTextColor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:actionMenuTextColor
        */
        public static final int Theme_actionMenuTextColor = 26;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeBackground
        */
        public static final int Theme_actionModeBackground = 29;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeCloseButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeCloseButtonStyle
        */
        public static final int Theme_actionModeCloseButtonStyle = 28;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeCloseDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeCloseDrawable
        */
        public static final int Theme_actionModeCloseDrawable = 31;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeCopyDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeCopyDrawable
        */
        public static final int Theme_actionModeCopyDrawable = 33;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeCutDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeCutDrawable
        */
        public static final int Theme_actionModeCutDrawable = 32;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeFindDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeFindDrawable
        */
        public static final int Theme_actionModeFindDrawable = 37;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModePasteDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModePasteDrawable
        */
        public static final int Theme_actionModePasteDrawable = 34;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModePopupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModePopupWindowStyle
        */
        public static final int Theme_actionModePopupWindowStyle = 39;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeSelectAllDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeSelectAllDrawable
        */
        public static final int Theme_actionModeSelectAllDrawable = 35;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeShareDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeShareDrawable
        */
        public static final int Theme_actionModeShareDrawable = 36;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeSplitBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeSplitBackground
        */
        public static final int Theme_actionModeSplitBackground = 30;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeStyle
        */
        public static final int Theme_actionModeStyle = 27;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionModeWebSearchDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionModeWebSearchDrawable
        */
        public static final int Theme_actionModeWebSearchDrawable = 38;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionOverflowButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionOverflowButtonStyle
        */
        public static final int Theme_actionOverflowButtonStyle = 15;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#actionOverflowMenuStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:actionOverflowMenuStyle
        */
        public static final int Theme_actionOverflowMenuStyle = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#activityChooserViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:activityChooserViewStyle
        */
        public static final int Theme_activityChooserViewStyle = 57;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#alertDialogButtonGroupStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:alertDialogButtonGroupStyle
        */
        public static final int Theme_alertDialogButtonGroupStyle = 91;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#alertDialogCenterButtons}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:alertDialogCenterButtons
        */
        public static final int Theme_alertDialogCenterButtons = 92;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#alertDialogStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:alertDialogStyle
        */
        public static final int Theme_alertDialogStyle = 90;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#alertDialogTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:alertDialogTheme
        */
        public static final int Theme_alertDialogTheme = 93;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowAnimationStyle}
          attribute's value can be found in the {@link #Theme} array.
          @attr name android:windowAnimationStyle
        */
        public static final int Theme_android_windowAnimationStyle = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowIsFloating}
          attribute's value can be found in the {@link #Theme} array.
          @attr name android:windowIsFloating
        */
        public static final int Theme_android_windowIsFloating = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#autoCompleteTextViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:autoCompleteTextViewStyle
        */
        public static final int Theme_autoCompleteTextViewStyle = 98;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#borderlessButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:borderlessButtonStyle
        */
        public static final int Theme_borderlessButtonStyle = 54;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonBarButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonBarButtonStyle
        */
        public static final int Theme_buttonBarButtonStyle = 51;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonBarNegativeButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonBarNegativeButtonStyle
        */
        public static final int Theme_buttonBarNegativeButtonStyle = 96;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonBarNeutralButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonBarNeutralButtonStyle
        */
        public static final int Theme_buttonBarNeutralButtonStyle = 97;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonBarPositiveButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonBarPositiveButtonStyle
        */
        public static final int Theme_buttonBarPositiveButtonStyle = 95;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonBarStyle
        */
        public static final int Theme_buttonBarStyle = 50;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonStyle
        */
        public static final int Theme_buttonStyle = 99;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#buttonStyleSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:buttonStyleSmall
        */
        public static final int Theme_buttonStyleSmall = 100;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#checkboxStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:checkboxStyle
        */
        public static final int Theme_checkboxStyle = 101;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#checkedTextViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:checkedTextViewStyle
        */
        public static final int Theme_checkedTextViewStyle = 102;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorAccent}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorAccent
        */
        public static final int Theme_colorAccent = 83;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorButtonNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorButtonNormal
        */
        public static final int Theme_colorButtonNormal = 87;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorControlActivated}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorControlActivated
        */
        public static final int Theme_colorControlActivated = 85;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorControlHighlight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorControlHighlight
        */
        public static final int Theme_colorControlHighlight = 86;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorControlNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorControlNormal
        */
        public static final int Theme_colorControlNormal = 84;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorPrimary}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorPrimary
        */
        public static final int Theme_colorPrimary = 81;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorPrimaryDark}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorPrimaryDark
        */
        public static final int Theme_colorPrimaryDark = 82;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#colorSwitchThumbNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:colorSwitchThumbNormal
        */
        public static final int Theme_colorSwitchThumbNormal = 88;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#controlBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:controlBackground
        */
        public static final int Theme_controlBackground = 89;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dialogPreferredPadding}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:dialogPreferredPadding
        */
        public static final int Theme_dialogPreferredPadding = 43;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dialogTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:dialogTheme
        */
        public static final int Theme_dialogTheme = 42;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dividerHorizontal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:dividerHorizontal
        */
        public static final int Theme_dividerHorizontal = 56;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dividerVertical}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:dividerVertical
        */
        public static final int Theme_dividerVertical = 55;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dropDownListViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:dropDownListViewStyle
        */
        public static final int Theme_dropDownListViewStyle = 73;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#dropdownListPreferredItemHeight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:dropdownListPreferredItemHeight
        */
        public static final int Theme_dropdownListPreferredItemHeight = 46;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#editTextBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:editTextBackground
        */
        public static final int Theme_editTextBackground = 63;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#editTextColor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:editTextColor
        */
        public static final int Theme_editTextColor = 62;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#editTextStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:editTextStyle
        */
        public static final int Theme_editTextStyle = 103;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#homeAsUpIndicator}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:homeAsUpIndicator
        */
        public static final int Theme_homeAsUpIndicator = 48;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listChoiceBackgroundIndicator}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:listChoiceBackgroundIndicator
        */
        public static final int Theme_listChoiceBackgroundIndicator = 80;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listDividerAlertDialog}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:listDividerAlertDialog
        */
        public static final int Theme_listDividerAlertDialog = 44;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPopupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:listPopupWindowStyle
        */
        public static final int Theme_listPopupWindowStyle = 74;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPreferredItemHeight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:listPreferredItemHeight
        */
        public static final int Theme_listPreferredItemHeight = 68;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPreferredItemHeightLarge}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:listPreferredItemHeightLarge
        */
        public static final int Theme_listPreferredItemHeightLarge = 70;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPreferredItemHeightSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:listPreferredItemHeightSmall
        */
        public static final int Theme_listPreferredItemHeightSmall = 69;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPreferredItemPaddingLeft}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:listPreferredItemPaddingLeft
        */
        public static final int Theme_listPreferredItemPaddingLeft = 71;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#listPreferredItemPaddingRight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:listPreferredItemPaddingRight
        */
        public static final int Theme_listPreferredItemPaddingRight = 72;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#panelBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:panelBackground
        */
        public static final int Theme_panelBackground = 77;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#panelMenuListTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:panelMenuListTheme
        */
        public static final int Theme_panelMenuListTheme = 79;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#panelMenuListWidth}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:panelMenuListWidth
        */
        public static final int Theme_panelMenuListWidth = 78;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#popupMenuStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:popupMenuStyle
        */
        public static final int Theme_popupMenuStyle = 60;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#popupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:popupWindowStyle
        */
        public static final int Theme_popupWindowStyle = 61;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#radioButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:radioButtonStyle
        */
        public static final int Theme_radioButtonStyle = 104;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#ratingBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:ratingBarStyle
        */
        public static final int Theme_ratingBarStyle = 105;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#searchViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:searchViewStyle
        */
        public static final int Theme_searchViewStyle = 67;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#selectableItemBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:selectableItemBackground
        */
        public static final int Theme_selectableItemBackground = 52;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#selectableItemBackgroundBorderless}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:selectableItemBackgroundBorderless
        */
        public static final int Theme_selectableItemBackgroundBorderless = 53;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#spinnerDropDownItemStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:spinnerDropDownItemStyle
        */
        public static final int Theme_spinnerDropDownItemStyle = 47;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#spinnerStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:spinnerStyle
        */
        public static final int Theme_spinnerStyle = 106;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#switchStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:switchStyle
        */
        public static final int Theme_switchStyle = 107;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceLargePopupMenu}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceLargePopupMenu
        */
        public static final int Theme_textAppearanceLargePopupMenu = 40;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceListItem}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceListItem
        */
        public static final int Theme_textAppearanceListItem = 75;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceListItemSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceListItemSmall
        */
        public static final int Theme_textAppearanceListItemSmall = 76;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceSearchResultSubtitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceSearchResultSubtitle
        */
        public static final int Theme_textAppearanceSearchResultSubtitle = 65;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceSearchResultTitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceSearchResultTitle
        */
        public static final int Theme_textAppearanceSearchResultTitle = 64;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textAppearanceSmallPopupMenu}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:textAppearanceSmallPopupMenu
        */
        public static final int Theme_textAppearanceSmallPopupMenu = 41;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textColorAlertDialogListItem}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:textColorAlertDialogListItem
        */
        public static final int Theme_textColorAlertDialogListItem = 94;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#textColorSearchUrl}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.revenuecat.purchases_sample:textColorSearchUrl
        */
        public static final int Theme_textColorSearchUrl = 66;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#toolbarNavigationButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:toolbarNavigationButtonStyle
        */
        public static final int Theme_toolbarNavigationButtonStyle = 59;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#toolbarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:toolbarStyle
        */
        public static final int Theme_toolbarStyle = 58;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowActionBar}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowActionBar
        */
        public static final int Theme_windowActionBar = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowActionBarOverlay}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowActionBarOverlay
        */
        public static final int Theme_windowActionBarOverlay = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowActionModeOverlay}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowActionModeOverlay
        */
        public static final int Theme_windowActionModeOverlay = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowFixedHeightMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowFixedHeightMajor
        */
        public static final int Theme_windowFixedHeightMajor = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowFixedHeightMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowFixedHeightMinor
        */
        public static final int Theme_windowFixedHeightMinor = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowFixedWidthMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowFixedWidthMajor
        */
        public static final int Theme_windowFixedWidthMajor = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowFixedWidthMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowFixedWidthMinor
        */
        public static final int Theme_windowFixedWidthMinor = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowMinWidthMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowMinWidthMajor
        */
        public static final int Theme_windowMinWidthMajor = 10;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowMinWidthMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowMinWidthMinor
        */
        public static final int Theme_windowMinWidthMinor = 11;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#windowNoTitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:windowNoTitle
        */
        public static final int Theme_windowNoTitle = 3;
        /** Attributes that can be used with a Toolbar.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Toolbar_android_gravity android:gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_android_minHeight android:minHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_collapseContentDescription com.revenuecat.purchases_sample:collapseContentDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_collapseIcon com.revenuecat.purchases_sample:collapseIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetEnd com.revenuecat.purchases_sample:contentInsetEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetLeft com.revenuecat.purchases_sample:contentInsetLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetRight com.revenuecat.purchases_sample:contentInsetRight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetStart com.revenuecat.purchases_sample:contentInsetStart}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_logo com.revenuecat.purchases_sample:logo}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_logoDescription com.revenuecat.purchases_sample:logoDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_maxButtonHeight com.revenuecat.purchases_sample:maxButtonHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_navigationContentDescription com.revenuecat.purchases_sample:navigationContentDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_navigationIcon com.revenuecat.purchases_sample:navigationIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_popupTheme com.revenuecat.purchases_sample:popupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitle com.revenuecat.purchases_sample:subtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitleTextAppearance com.revenuecat.purchases_sample:subtitleTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitleTextColor com.revenuecat.purchases_sample:subtitleTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_title com.revenuecat.purchases_sample:title}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginBottom com.revenuecat.purchases_sample:titleMarginBottom}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginEnd com.revenuecat.purchases_sample:titleMarginEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginStart com.revenuecat.purchases_sample:titleMarginStart}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginTop com.revenuecat.purchases_sample:titleMarginTop}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMargins com.revenuecat.purchases_sample:titleMargins}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleTextAppearance com.revenuecat.purchases_sample:titleTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleTextColor com.revenuecat.purchases_sample:titleTextColor}</code></td><td></td></tr>
           </table>
           @see #Toolbar_android_gravity
           @see #Toolbar_android_minHeight
           @see #Toolbar_collapseContentDescription
           @see #Toolbar_collapseIcon
           @see #Toolbar_contentInsetEnd
           @see #Toolbar_contentInsetLeft
           @see #Toolbar_contentInsetRight
           @see #Toolbar_contentInsetStart
           @see #Toolbar_logo
           @see #Toolbar_logoDescription
           @see #Toolbar_maxButtonHeight
           @see #Toolbar_navigationContentDescription
           @see #Toolbar_navigationIcon
           @see #Toolbar_popupTheme
           @see #Toolbar_subtitle
           @see #Toolbar_subtitleTextAppearance
           @see #Toolbar_subtitleTextColor
           @see #Toolbar_title
           @see #Toolbar_titleMarginBottom
           @see #Toolbar_titleMarginEnd
           @see #Toolbar_titleMarginStart
           @see #Toolbar_titleMarginTop
           @see #Toolbar_titleMargins
           @see #Toolbar_titleTextAppearance
           @see #Toolbar_titleTextColor
         */
        public static final int[] Toolbar = {
            0x010100af, 0x01010140, 0x7f010003, 0x7f010006,
            0x7f01000a, 0x7f010016, 0x7f010017, 0x7f010018,
            0x7f010019, 0x7f01001b, 0x7f0100d2, 0x7f0100d3,
            0x7f0100d4, 0x7f0100d5, 0x7f0100d6, 0x7f0100d7,
            0x7f0100d8, 0x7f0100d9, 0x7f0100da, 0x7f0100db,
            0x7f0100dc, 0x7f0100dd, 0x7f0100de, 0x7f0100df,
            0x7f0100e0
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#gravity}
          attribute's value can be found in the {@link #Toolbar} array.
          @attr name android:gravity
        */
        public static final int Toolbar_android_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#minHeight}
          attribute's value can be found in the {@link #Toolbar} array.
          @attr name android:minHeight
        */
        public static final int Toolbar_android_minHeight = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#collapseContentDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:collapseContentDescription
        */
        public static final int Toolbar_collapseContentDescription = 19;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#collapseIcon}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:collapseIcon
        */
        public static final int Toolbar_collapseIcon = 18;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetEnd}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetEnd
        */
        public static final int Toolbar_contentInsetEnd = 6;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetLeft}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetLeft
        */
        public static final int Toolbar_contentInsetLeft = 7;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetRight}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetRight
        */
        public static final int Toolbar_contentInsetRight = 8;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#contentInsetStart}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:contentInsetStart
        */
        public static final int Toolbar_contentInsetStart = 5;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#logo}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:logo
        */
        public static final int Toolbar_logo = 4;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#logoDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:logoDescription
        */
        public static final int Toolbar_logoDescription = 22;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#maxButtonHeight}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:maxButtonHeight
        */
        public static final int Toolbar_maxButtonHeight = 17;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#navigationContentDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:navigationContentDescription
        */
        public static final int Toolbar_navigationContentDescription = 21;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#navigationIcon}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:navigationIcon
        */
        public static final int Toolbar_navigationIcon = 20;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#popupTheme}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:popupTheme
        */
        public static final int Toolbar_popupTheme = 9;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitle}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:subtitle
        */
        public static final int Toolbar_subtitle = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitleTextAppearance}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:subtitleTextAppearance
        */
        public static final int Toolbar_subtitleTextAppearance = 11;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#subtitleTextColor}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:subtitleTextColor
        */
        public static final int Toolbar_subtitleTextColor = 24;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#title}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:title
        */
        public static final int Toolbar_title = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleMarginBottom}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleMarginBottom
        */
        public static final int Toolbar_titleMarginBottom = 16;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleMarginEnd}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleMarginEnd
        */
        public static final int Toolbar_titleMarginEnd = 14;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleMarginStart}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleMarginStart
        */
        public static final int Toolbar_titleMarginStart = 13;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleMarginTop}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleMarginTop
        */
        public static final int Toolbar_titleMarginTop = 15;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleMargins}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleMargins
        */
        public static final int Toolbar_titleMargins = 12;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleTextAppearance}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:titleTextAppearance
        */
        public static final int Toolbar_titleTextAppearance = 10;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#titleTextColor}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:titleTextColor
        */
        public static final int Toolbar_titleTextColor = 23;
        /** Attributes that can be used with a View.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #View_android_focusable android:focusable}</code></td><td></td></tr>
           <tr><td><code>{@link #View_android_theme android:theme}</code></td><td></td></tr>
           <tr><td><code>{@link #View_paddingEnd com.revenuecat.purchases_sample:paddingEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #View_paddingStart com.revenuecat.purchases_sample:paddingStart}</code></td><td></td></tr>
           <tr><td><code>{@link #View_theme com.revenuecat.purchases_sample:theme}</code></td><td></td></tr>
           </table>
           @see #View_android_focusable
           @see #View_android_theme
           @see #View_paddingEnd
           @see #View_paddingStart
           @see #View_theme
         */
        public static final int[] View = {
            0x01010000, 0x010100da, 0x7f0100e1, 0x7f0100e2,
            0x7f0100e3
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#focusable}
          attribute's value can be found in the {@link #View} array.
          @attr name android:focusable
        */
        public static final int View_android_focusable = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#theme}
          attribute's value can be found in the {@link #View} array.
          @attr name android:theme
        */
        public static final int View_android_theme = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#paddingEnd}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:paddingEnd
        */
        public static final int View_paddingEnd = 3;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#paddingStart}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:paddingStart
        */
        public static final int View_paddingStart = 2;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#theme}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.revenuecat.purchases_sample:theme
        */
        public static final int View_theme = 4;
        /** Attributes that can be used with a ViewBackgroundHelper.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_android_background android:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_backgroundTint com.revenuecat.purchases_sample:backgroundTint}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_backgroundTintMode com.revenuecat.purchases_sample:backgroundTintMode}</code></td><td></td></tr>
           </table>
           @see #ViewBackgroundHelper_android_background
           @see #ViewBackgroundHelper_backgroundTint
           @see #ViewBackgroundHelper_backgroundTintMode
         */
        public static final int[] ViewBackgroundHelper = {
            0x010100d4, 0x7f0100e4, 0x7f0100e5
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#background}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.
          @attr name android:background
        */
        public static final int ViewBackgroundHelper_android_background = 0;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundTint}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.revenuecat.purchases_sample:backgroundTint
        */
        public static final int ViewBackgroundHelper_backgroundTint = 1;
        /**
          <p>This symbol is the offset where the {@link com.revenuecat.purchases_sample.R.attr#backgroundTintMode}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
          @attr name com.revenuecat.purchases_sample:backgroundTintMode
        */
        public static final int ViewBackgroundHelper_backgroundTintMode = 2;
        /** Attributes that can be used with a ViewStubCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ViewStubCompat_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewStubCompat_android_inflatedId android:inflatedId}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewStubCompat_android_layout android:layout}</code></td><td></td></tr>
           </table>
           @see #ViewStubCompat_android_id
           @see #ViewStubCompat_android_inflatedId
           @see #ViewStubCompat_android_layout
         */
        public static final int[] ViewStubCompat = {
            0x010100d0, 0x010100f2, 0x010100f3
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:id
        */
        public static final int ViewStubCompat_android_id = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#inflatedId}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:inflatedId
        */
        public static final int ViewStubCompat_android_inflatedId = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:layout
        */
        public static final int ViewStubCompat_android_layout = 1;
    };
}
